@@ -149,7 +149,7 @@ class PagureMilter(Milter.Base):
             self.log(
                 "No valid recipient email found in To/Cc: %s" % email_address
             )
-            return Milter.CONTINUE
+            return Milter.ACCEPT
 
         if msg["From"] and msg["From"] == _config.get("FROM_EMAIL"):
             self.log("Let's not process the email we send")
@@ -158,6 +158,11 @@ class PagureMilter(Milter.Base):
         msg_id = msg.get("In-Reply-To", None)
         if msg_id is None:
             self.log("No In-Reply-To, can't process this message.")
+            self.setreply(
+                "554",
+                xcode="5.5.0",
+                msg="Replies to Pagure must have an In-Reply-To header field."
+            )
             return Milter.REJECT
 
         # Ensure we don't get extra lines in the message-id
@@ -203,22 +208,58 @@ class PagureMilter(Milter.Base):
             self.log("tohash:    %s" % tohash)
             self.log("Hash does not correspond to the destination")
             session.remove()
+            self.setreply(
+                "550", xcode="5.7.1", msg="Reply authentication failed."
+            )
             return Milter.REJECT
 
         msg_id = clean_item(msg_id)
 
-        if msg_id and "-ticket-" in msg_id:
-            self.log("Processing issue")
-            session.remove()
-            return self.handle_ticket_email(msg, msg_id)
-        elif msg_id and "-pull-request-" in msg_id:
-            self.log("Processing pull-request")
-            session.remove()
-            return self.handle_request_email(msg, msg_id)
-        else:
-            self.log("Not a pagure ticket or pull-request email, let it go")
-            session.remove()
-            return Milter.CONTINUE
+        try:
+            if msg_id and "-ticket-" in msg_id:
+                self.log("Processing issue")
+                session.remove()
+                return self.handle_ticket_email(msg, msg_id)
+            elif msg_id and "-pull-request-" in msg_id:
+                self.log("Processing pull-request")
+                session.remove()
+                return self.handle_request_email(msg, msg_id)
+            else:
+                # msg_id passed the hash check, and yet wasn't recognized as
+                # a message ID generated by Pagure. This is probably a bug,
+                # because it should be impossible unless an attacker has
+                # acquired the secret "salt" or broken the hash algorithm.
+                self.log(
+                    "Not a pagure ticket or pull-request email, rejecting it."
+                )
+                session.remove()
+                self.setreply(
+                    "554",
+                    xcode="5.3.5",
+                    msg="Pagure couldn't determine how to handle the message."
+                )
+                return Milter.REJECT
+        except requests.ReadTimeout as e:
+            self.setreply(
+                "451",
+                xcode="4.4.2",
+                msg="The comment couldn't be added: " + str(e)
+            )
+            return Milter.TEMPFAIL
+        except requests.ConnectionError as e:
+            self.setreply(
+                "451",
+                xcode="4.4.1",
+                msg="The comment couldn't be added: " + str(e)
+            )
+            return Milter.TEMPFAIL
+        except requests.RequestException as e:
+            self.setreply(
+                "554",
+                xcode="5.3.0",
+                msg="The comment couldn't be added: " + str(e)
+            )
+            return Milter.REJECT
 
     def handle_ticket_email(self, emailobj, msg_id):
         """ Add the email as a comment on a ticket. """
@@ -245,10 +286,23 @@ class PagureMilter(Milter.Base):
         req = requests.put(url, data=data)
         if req.status_code == 200:
             self.log("Comment added")
-            return Milter.ACCEPT
+            # The message is now effectively delivered. Tell the MTA to accept
+            # and discard it.
+            # If you want the message to be processed by another milter after
+            # DISCARD one, or delivered to a mailbox the usual way, then change
+            # DROP to ACCEPT.
+            return Milter.DISCARD
         self.log("Could not add the comment to ticket to pagure")
         self.log(req.text)
 
+        self.setreply(
+            "554",
+            xcode="5.3.0",
+            msg=(
+                "The comment couldn't be added to the issue. "
+                + "HTTP status: %d %s." % (req.status_code, req.reason)
+            )
+        )
         return Milter.REJECT
 
     def handle_request_email(self, emailobj, msg_id):
@@ -276,10 +330,23 @@ class PagureMilter(Milter.Base):
         req = requests.put(url, data=data)
         if req.status_code == 200:
             self.log("Comment added on PR")
-            return Milter.ACCEPT
+            # The message is now effectively delivered. Tell the MTA to accept
+            # and discard it.
+            # If you want the message to be processed by another milter after
+            # this one, or delivered to a mailbox the usual way, then change
+            # DISCARD to ACCEPT.
+            return Milter.DISCARD
         self.log("Could not add the comment to PR to pagure")
         self.log(req.text)
 
+        self.setreply(
+            "554",
+            xcode="5.3.0",
+            msg=(
+                "The comment couldn't be added to the pull request. "
+                + "HTTP status: %d %s." % (req.status_code, req.reason)
+            )
+        )
         return Milter.REJECT
 
 
