@@ -20,6 +20,7 @@ import codecs
 import functools
 import logging
 import os
+import sys
 
 import docutils
 import enum
@@ -44,6 +45,9 @@ from pagure.utils import authenticated, check_api_acls  # noqa: E402
 
 _log = logging.getLogger(__name__)
 
+# Mitigate bug in flask-wtf 0.14.2 on EL8 for 5.14.1 release
+sys.modules["werkzeug.url_encode"] = "werkzeug.urls.url_encode"
+
 
 def preload_docs(endpoint):
     """ Utility to load an RST file and turn it into fancy HTML. """
@@ -75,8 +79,7 @@ def build_docs_section(name, endpoints):
 
 
 class APIERROR(enum.Enum):
-    """ Clast listing as Enum all the possible error thrown by the API.
-    """
+    """Clast listing as Enum all the possible error thrown by the API."""
 
     ENOCODE = "Variable message describing the issue"
     ENOPROJECT = "Project not found"
@@ -114,6 +117,9 @@ class APIERROR(enum.Enum):
     ENEWPROJECTDISABLED = (
         "Creating project have been disabled for this instance"
     )
+    ENEWPROJECTFORBIDDEN = (
+        "You are not allowed to create new projects on this instance"
+    )
     ETIMESTAMP = "Invalid timestamp format"
     EDATETIME = "Invalid datetime format"
     EINVALIDISSUEFIELD = "Invalid custom field submitted"
@@ -161,11 +167,17 @@ def get_authorized_api_project(session, repo, user=None, namespace=None):
 
 
 def get_request_data():
-    return flask.request.form or flask.request.get_json() or {}
+    # Check if it's JSON or form data
+    if flask.request.headers.get("Content-Type") == "application/json":
+        # Set force to True to ignore the mimetype. Set silent so that None is
+        # returned if it's invalid JSON.
+        return flask.request.get_json(force=True, silent=True) or {}
+    else:
+        return flask.request.form or flask.request.get_json() or {}
 
 
 def api_login_required(acls=None, optional=False):
-    """ Decorator used to indicate that authentication is required for some
+    """Decorator used to indicate that authentication is required for some
     API endpoint.
 
     :arg acls: A list of access control
@@ -221,7 +233,7 @@ def api_login_required(acls=None, optional=False):
 
 
 def api_login_optional(acls=None):
-    """ Decorator used to indicate that authentication is optional for some
+    """Decorator used to indicate that authentication is optional for some
     API endpoint.
     """
 
@@ -278,7 +290,7 @@ def api_method(function):
 
 
 def get_page():
-    """ Returns the page value specified in the request.
+    """Returns the page value specified in the request.
     Defaults to 1.
     raises APIERROR.EINVALIDREQ if the page provided isn't an integer
     raises APIERROR.EINVALIDREQ if the page provided is lower than 1
@@ -304,7 +316,7 @@ def get_page():
 
 
 def get_per_page():
-    """ Returns the per_page value specified in the request.
+    """Returns the per_page value specified in the request.
     Defaults to 20.
     raises APIERROR.EINVALIDREQ if the page provided isn't an integer
     raises APIERROR.EINVALIDPERPAGEVALUE if the page provided is lower
@@ -528,9 +540,14 @@ def api():
         project.api_project_tag_delete,
         project.api_git_tags,
         project.api_new_git_tags,
+        project.api_git_branches,
+        project.api_list_git_alias,
+        project.api_new_git_alias,
+        project.api_drop_git_alias,
         project.api_project_git_urls,
         project.api_project_watchers,
-        project.api_git_branches,
+        project.api_project_contributors,
+        project.api_project_hascommit,
         project.api_new_branch,
         project.api_fork_project,
         project.api_modify_acls,
@@ -579,6 +596,7 @@ def api():
         fork.api_pull_request_merge,
         fork.api_pull_request_rebase,
         fork.api_pull_request_close,
+        fork.api_pull_request_reopen,
         fork.api_pull_request_add_comment,
         fork.api_pull_request_add_flag,
         fork.api_pull_request_get_flag,
@@ -599,7 +617,12 @@ def api():
     ]
     sections.append(build_docs_section("users", users_methods))
 
-    groups_methods = [group.api_groups, group.api_view_group]
+    groups_methods = [
+        group.api_groups,
+        group.api_view_group,
+        group.api_group_add_member,
+        group.api_group_remove_member,
+    ]
     sections.append(build_docs_section("groups", groups_methods))
 
     plugins_methods = [
