@@ -503,7 +503,7 @@ def api_pull_request_update(repo, requestid, username=None, namespace=None):
     _check_token(repo, project_token=False)
 
     request = _get_request(repo, requestid)
-    _check_pull_request_access(request, assignee=True)
+    _check_pull_request_access(request, assignee=True, allow_author=True)
 
     form = pagure.forms.RequestPullForm(csrf_enabled=False)
     if not form.validate_on_submit():
@@ -770,10 +770,13 @@ def api_pull_request_close(repo, requestid, username=None, namespace=None):
 
     repo = _get_repo(repo, username, namespace)
     _check_pull_request(repo)
-    _check_token(repo)
+    _check_token(repo, project_token=False)
     request = _get_request(repo, requestid)
 
-    if not is_repo_committer(repo):
+    if (
+        not is_repo_committer(repo)
+        and not flask.g.fas_user.username == request.user.username
+    ):
         raise pagure.exceptions.APIError(403, error_code=APIERROR.ENOPRCLOSE)
 
     try:
@@ -791,6 +794,74 @@ def api_pull_request_close(repo, requestid, username=None, namespace=None):
     return jsonout
 
 
+@API.route("/<repo>/pull-request/<int:requestid>/reopen", methods=["POST"])
+@API.route(
+    "/<namespace>/<repo>/pull-request/<int:requestid>/reopen", methods=["POST"]
+)
+@API.route(
+    "/fork/<username>/<repo>/pull-request/<int:requestid>/reopen",
+    methods=["POST"],
+)
+@API.route(
+    "/fork/<username>/<namespace>/<repo>/pull-request/<int:requestid>/reopen",
+    methods=["POST"],
+)
+@api_login_required(acls=["pull_request_close", "pull_request_update"])
+@api_method
+def api_pull_request_reopen(repo, requestid, username=None, namespace=None):
+    """
+    Reopen a pull-request
+    --------------------
+    Instruct Pagure to reopen a pull request.
+
+    ::
+
+        POST /api/0/<repo>/pull-request/<request id>/reopen
+        POST /api/0/<namespace>/<repo>/pull-request/<request id>/reopen
+
+    ::
+
+        POST /api/0/fork/<username>/<repo>/pull-request/<request id>/reopen
+        POST /api/0/fork/<username>/<namespace>/<repo>/pull-request/<request id>/reopen
+
+    Sample response
+    ^^^^^^^^^^^^^^^
+
+    ::
+
+        {
+          "message": "Pull-request reopened!"
+        }
+
+    """  # noqa
+    output = {}
+
+    repo = _get_repo(repo, username, namespace)
+    _check_pull_request(repo)
+    _check_token(repo, project_token=False)
+    request = _get_request(repo, requestid)
+
+    if (
+        not is_repo_committer(repo)
+        and not flask.g.fas_user.username == request.user.username
+    ):
+        raise pagure.exceptions.APIError(403, error_code=APIERROR.ENOPRCLOSE)
+
+    try:
+        pagure.lib.query.reopen_pull_request(
+            flask.g.session, request, flask.g.fas_user.username
+        )
+        flask.g.session.commit()
+        output["message"] = "Pull-request reopened!"
+    except SQLAlchemyError as err:  # pragma: no cover
+        flask.g.session.rollback()
+        _log.exception(err)
+        raise pagure.exceptions.APIError(400, error_code=APIERROR.EDBERROR)
+
+    jsonout = flask.jsonify(output)
+    return jsonout
+
+
 @API.route("/<repo>/pull-request/<int:requestid>/comment", methods=["POST"])
 @API.route(
     "/<namespace>/<repo>/pull-request/<int:requestid>/comment",
@@ -928,6 +999,13 @@ def api_pull_request_add_flag(repo, requestid, username=None, namespace=None):
     -------------------
     Add or edit flags on a pull-request.
 
+    This is an utility method which add a flag to the latest commit of the
+    specified pull-request.
+
+    Note that using it has a risk of race-condition if the pull-request changes
+    at the time the flag is being added. Using the commit flag endpoint prevents
+    this risk of race-condition.
+
     ::
 
         POST /api/0/<repo>/pull-request/<request id>/flag
@@ -1064,9 +1142,27 @@ def api_pull_request_add_flag(repo, requestid, username=None, namespace=None):
                     else pagure_config["FLAG_FAILURE"]
                 )
         try:
+            if not request.commit_stop:
+                repopath = None
+                parentpath = pagure.utils.get_repo_path(request.project)
+                if request.remote:
+                    repopath = pagure.utils.get_remote_repo_path(
+                        request.remote_git, request.branch_from
+                    )
+                elif request.project_from:
+                    repopath = pagure.utils.get_repo_path(request.project_from)
+
+                repo_obj = None
+                if repopath:
+                    repo_obj = pygit2.Repository(repopath)
+                orig_repo = pygit2.Repository(parentpath)
+                pagure.lib.git.diff_pull_request(
+                    flask.g.session, request, repo_obj, orig_repo
+                )
+
             # New Flag
             message, uid = pagure.lib.query.add_pull_request_flag(
-                flask.g.session,
+                session=flask.g.session,
                 request=request,
                 username=username,
                 status=status,
@@ -1078,8 +1174,8 @@ def api_pull_request_add_flag(repo, requestid, username=None, namespace=None):
                 token=flask.g.token.id,
             )
             flask.g.session.commit()
-            pr_flag = pagure.lib.query.get_pull_request_flag_by_uid(
-                flask.g.session, request, uid
+            pr_flag = pagure.lib.query.get_commit_flag_by_uid(
+                flask.g.session, request.commit_stop, uid
             )
             output["message"] = message
             output["uid"] = uid
@@ -1182,9 +1278,31 @@ def api_pull_request_get_flag(repo, requestid, username=None, namespace=None):
     _check_pull_request(repo)
     request = _get_request(repo, requestid)
 
+    if not request.commit_stop:
+        repopath = None
+        parentpath = pagure.utils.get_repo_path(request.project)
+        if request.remote:
+            repopath = pagure.utils.get_remote_repo_path(
+                request.remote_git, request.branch_from
+            )
+        elif request.project_from:
+            repopath = pagure.utils.get_repo_path(request.project_from)
+
+        repo_obj = None
+        if repopath:
+            repo_obj = pygit2.Repository(repopath)
+        orig_repo = pygit2.Repository(parentpath)
+        pagure.lib.git.diff_pull_request(
+            flask.g.session, request, repo_obj, orig_repo
+        )
+
     output = {"flags": []}
 
-    for flag in request.flags:
+    flags = pagure.lib.query.get_commit_flag(
+        flask.g.session, request.project, request.commit_stop
+    )
+
+    for flag in flags:
         output["flags"].append(flag.to_json(public=True))
 
     jsonout = flask.jsonify(output)
@@ -1353,6 +1471,11 @@ def api_pull_request_create(repo, username=None, namespace=None):
     |                       |          |             | changes are about.     |
     +-----------------------+----------+-------------+------------------------+
 
+    Note: If f the repo you're opening the PR against is not the same as the
+    repo from which the changes originates, you must provide the ``repo_from``
+    and ``repo_from_username`` (and potentially ``repo_from_namespace``)
+    corresponding to the fork.
+
     Sample response
     ^^^^^^^^^^^^^^^
 
