@@ -194,12 +194,14 @@ def _check_private_issue_access(issue):
         )
 
 
-def _check_pull_request_access(request, assignee=False):
+def _check_pull_request_access(request, assignee=False, allow_author=False):
     """Check if user can access Pull-Request. Must be repo committer
-    or author to see private pull-requests.
+    or author (if flag is true) to see private pull-requests.
     :param request: PullRequest object
     :param assignee: a boolean specifying whether to allow the assignee or not
         defaults to False
+    :param allow_author: a boolean specifying whether the PR author should be
+        allowed, defaults to False
     :raises pagure.exceptions.APIError: when access denied
     """
     # Private PRs require commit access
@@ -207,7 +209,9 @@ def _check_pull_request_access(request, assignee=False):
 
     error = False
     # Public tickets require ticket access
-    error = not is_repo_user(request.project)
+    error = not is_repo_user(request.project) and not (
+        allow_author and request.user.user == flask.g.fas_user.username
+    )
 
     if assignee:
         if (
