@@ -31,6 +31,7 @@ if "PAGURE_CONFIG" not in os.environ and os.path.exists(
 import pagure.config  # noqa: E402
 import pagure.exceptions  # noqa: E402
 import pagure.lib.git  # noqa: E402
+import pagure.lib.model  # noqa: E402
 import pagure.lib.model_base  # noqa: E402
 import pagure.lib.query  # noqa: E402
 import pagure.lib.tasks_utils  # noqa: E402
@@ -53,12 +54,12 @@ WATCH = {
 
 
 def _parser_refresh_gitolite(subparser):
-    """ Set up the CLI argument parser for the refresh-gitolite action.
+    """Set up the CLI argument parser for the refresh-gitolite action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
 
-     """
+    """
     local_parser = subparser.add_parser(
         "refresh-gitolite", help="Re-generate the gitolite config file"
     )
@@ -82,7 +83,7 @@ def _parser_refresh_gitolite(subparser):
 
 
 def _parser_refresh_ssh(subparser):
-    """ Set up the CLI argument parser for the refresh-ssh action.
+    """Set up the CLI argument parser for the refresh-ssh action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -96,7 +97,7 @@ def _parser_refresh_ssh(subparser):
 
 
 def _parser_clear_hook_token(subparser):
-    """ Set up the CLI argument parser for the clear-hook-token action.
+    """Set up the CLI argument parser for the clear-hook-token action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -110,7 +111,7 @@ def _parser_clear_hook_token(subparser):
 
 
 def _parser_admin_token_list(subparser):
-    """ Set up the CLI argument parser for the admin-token list action.
+    """Set up the CLI argument parser for the admin-token list action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -145,7 +146,7 @@ def _parser_admin_token_list(subparser):
 
 
 def _parser_admin_token_info(subparser):
-    """ Set up the CLI argument parser for the admin-token info action.
+    """Set up the CLI argument parser for the admin-token info action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -159,7 +160,7 @@ def _parser_admin_token_info(subparser):
 
 
 def _parser_admin_token_expire(subparser):
-    """ Set up the CLI argument parser for the admin-token expire action.
+    """Set up the CLI argument parser for the admin-token expire action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -180,7 +181,7 @@ def _parser_admin_token_expire(subparser):
 
 
 def _parser_admin_token_create(subparser):
-    """ Set up the CLI argument parser for the admin-token create action.
+    """Set up the CLI argument parser for the admin-token create action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -198,7 +199,7 @@ def _parser_admin_token_create(subparser):
 
 
 def _parser_admin_token_update(subparser):
-    """ Set up the CLI argument parser for the admin-token update action.
+    """Set up the CLI argument parser for the admin-token update action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -220,7 +221,7 @@ def _parser_admin_token_update(subparser):
 
 
 def _parser_admin_token(subparser):
-    """ Set up the CLI argument parser for the admin-token action.
+    """Set up the CLI argument parser for the admin-token action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -245,7 +246,7 @@ def _parser_admin_token(subparser):
 
 
 def _parser_get_watch(subparser):
-    """ Set up the CLI argument parser for the get-watch action.
+    """Set up the CLI argument parser for the get-watch action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -265,7 +266,7 @@ def _parser_get_watch(subparser):
 
 
 def _parser_update_watch(subparser):
-    """ Set up the CLI argument parser for the update-watch action.
+    """Set up the CLI argument parser for the update-watch action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -290,7 +291,7 @@ def _parser_update_watch(subparser):
 
 
 def _parser_read_only(subparser):
-    """ Set up the CLI argument parser for the read-only action.
+    """Set up the CLI argument parser for the read-only action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -316,7 +317,7 @@ def _parser_read_only(subparser):
 
 
 def _parser_new_group(subparser):
-    """ Set up the CLI argument parser for the new-group action.
+    """Set up the CLI argument parser for the new-group action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -339,7 +340,7 @@ def _parser_new_group(subparser):
 
 
 def _parser_list_groups(subparser):
-    """ Set up the CLI argument parser for the list-groups action.
+    """Set up the CLI argument parser for the list-groups action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -352,7 +353,7 @@ def _parser_list_groups(subparser):
 
 
 def _parser_block_user(subparser):
-    """ Set up the CLI argument parser for the block-user action.
+    """Set up the CLI argument parser for the block-user action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
@@ -383,7 +384,7 @@ def _parser_block_user(subparser):
 
 
 def _parser_upload_repospanner_hooks(subparser):
-    """ Set up the CLI argument parser to upload repospanner hook.
+    """Set up the CLI argument parser to upload repospanner hook.
 
     Args:
         subparser: An argparse subparser
@@ -398,7 +399,7 @@ def _parser_upload_repospanner_hooks(subparser):
 
 
 def _parser_ensure_project_hooks(subparser):
-    """ Set up the CLI argument parser to ensure project hooks are setup
+    """Set up the CLI argument parser to ensure project hooks are setup
 
     Args:
         subparser: An argparse subparser
@@ -414,12 +415,12 @@ def _parser_ensure_project_hooks(subparser):
 
 
 def _parser_delete_project(subparser):
-    """ Set up the CLI argument parser for the delete-project action.
+    """Set up the CLI argument parser for the delete-project action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
 
-     """
+    """
     local_parser = subparser.add_parser(
         "delete-project", help="Delete the project specified"
     )
@@ -439,13 +440,37 @@ def _parser_delete_project(subparser):
     local_parser.set_defaults(func=do_delete_project)
 
 
-def _parser_create_branch(subparser):
-    """ Set up the CLI argument parser for the create-branch action.
+def _parser_sanitize_spam_user(subparser):
+    """Set up the CLI argument parser for the delete-user-activity action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
 
-     """
+    """
+    local_parser = subparser.add_parser(
+        "sanitize-spam-user",
+        help="Delete repos and tickets by the user specified",
+    )
+
+    local_parser.add_argument(
+        "user",
+        help="Username of the spam user to sanitize",
+    )
+    local_parser.add_argument(
+        "action_user",
+        help="Username of the admin user doing the action (ie: deleting the "
+        "users activity)",
+    )
+    local_parser.set_defaults(func=do_sanitize_spam_user)
+
+
+def _parser_create_branch(subparser):
+    """Set up the CLI argument parser for the create-branch action.
+
+    :arg subparser: an argparse subparser allowing to have action's specific
+        arguments
+
+    """
     local_parser = subparser.add_parser(
         "create-branch",
         help="Create the specified branch in the specified project",
@@ -480,12 +505,12 @@ def _parser_create_branch(subparser):
 
 
 def _parser_set_default_branch(subparser):
-    """ Set up the CLI argument parser for the set-default-branch action.
+    """Set up the CLI argument parser for the set-default-branch action.
 
     :arg subparser: an argparse subparser allowing to have action's specific
         arguments
 
-     """
+    """
     local_parser = subparser.add_parser(
         "set-default-branch", help="Set the specified branch as default"
     )
@@ -503,6 +528,23 @@ def _parser_set_default_branch(subparser):
     local_parser.set_defaults(func=do_set_default_branch)
 
 
+def _parser_update_acls(subparser):
+    """Set up the CLI argument parser for the update-acls action.
+
+    :arg subparser: an argparse subparser allowing to have action's specific
+        arguments
+
+    """
+
+    local_parser = subparser.add_parser(
+        "update-acls",
+        help="Update the ACLs stored in the database with the ones defined "
+        "in the configuration file (addition only, no ACLs are removed from "
+        "the database).",
+    )
+    local_parser.set_defaults(func=do_update_acls)
+
+
 def parse_arguments(args=None):
     """ Set-up the argument parsing. """
     parser = argparse.ArgumentParser(
@@ -561,18 +603,23 @@ def parse_arguments(args=None):
     # delete-project
     _parser_delete_project(subparser)
 
+    # delete-all-user-acitvity
+    _parser_sanitize_spam_user(subparser)
+
     # create-branch
     _parser_create_branch(subparser)
 
     # set-default-branch
     _parser_set_default_branch(subparser)
 
+    # update-acls
+    _parser_update_acls(subparser)
+
     return parser.parse_args(args)
 
 
 def _ask_confirmation():
-    """ Ask to confirm an action.
-    """
+    """Ask to confirm an action."""
     action = input("Do you want to continue? [y/N]")
     return action.lower() in ["y", "yes"]
 
@@ -583,8 +630,7 @@ def _get_input(text):
 
 
 def _get_project(arg_project, user=None):
-    """ From the project specified to the CLI, extract the actual project.
-    """
+    """From the project specified to the CLI, extract the actual project."""
     namespace = None
     if "/" in arg_project:
         if arg_project.count("/") > 1:
@@ -613,7 +659,7 @@ def _check_project(_project, **kwargs):
 
 
 def do_generate_acl(args):
-    """ Regenerate the gitolite ACL file.
+    """Regenerate the gitolite ACL file.
 
 
     :arg args: the argparse object returned by ``parse_arguments()``.
@@ -667,7 +713,7 @@ def do_generate_acl(args):
 
 
 def do_refresh_ssh(_):
-    """ Regenerate the user key files.
+    """Regenerate the user key files.
 
     :arg _: the argparse object returned by ``parse_arguments()``, which is
         ignored as there are no argument to pass to this action.
@@ -685,7 +731,7 @@ def do_refresh_ssh(_):
 
 
 def do_generate_hook_token(_):
-    """ Regenerate the hook_token for each projects in the DB.
+    """Regenerate the hook_token for each projects in the DB.
 
     :arg _: the argparse object returned by ``parse_arguments()``, which is
         ignored as there are no argument to pass to this action.
@@ -702,7 +748,7 @@ def do_generate_hook_token(_):
 
 
 def do_list_admin_token(args):
-    """ List the admin token.
+    """List the admin token.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -727,7 +773,7 @@ def do_list_admin_token(args):
 
 
 def do_info_admin_token(args):
-    """ Print out information about the specified API token.
+    """Print out information about the specified API token.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -745,7 +791,7 @@ def do_info_admin_token(args):
 
 
 def do_expire_admin_token(args):
-    """ Expire a specific admin token.
+    """Expire a specific admin token.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -774,7 +820,7 @@ def do_expire_admin_token(args):
 
 
 def do_update_admin_token(args):
-    """ Update the expiration date of an admin token.
+    """Update the expiration date of an admin token.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -822,7 +868,7 @@ def do_update_admin_token(args):
 
 
 def do_create_admin_token(args):
-    """ Create a new admin token.
+    """Create a new admin token.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -871,7 +917,7 @@ def do_create_admin_token(args):
 
 
 def do_delete_project(args):
-    """ Delete a project.
+    """Delete a project.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -906,8 +952,172 @@ def do_delete_project(args):
     print("Project deleted")
 
 
+def do_sanitize_spam_user(args):
+    """Block and remove activity by a spam user
+
+    :arg args: the argparse object returned by ``parse_arguments()``.
+
+    """
+    _log.debug("user:          %s", args.user)
+    _log.debug("user deleting: %s", args.action_user)
+
+    # Validate users
+    user = pagure.lib.query.get_user(session, args.user)
+    action_user = pagure.lib.query.get_user(session, args.action_user)
+
+    projects = (
+        session.query(pagure.lib.model.Project).filter(
+            pagure.lib.model.Project.user_id == user.id
+        )
+    ).all()
+
+    issues = (
+        session.query(pagure.lib.model.Issue).filter(
+            pagure.lib.model.Issue.user_id == user.id
+        )
+    ).all()
+
+    comments = (
+        session.query(pagure.lib.model.IssueComment).filter(
+            pagure.lib.model.IssueComment.user_id == user.id
+        )
+    ).all()
+
+    prs = (
+        session.query(pagure.lib.model.PullRequest).filter(
+            pagure.lib.model.PullRequest.user_id == user.id
+        )
+    ).all()
+
+    prcomments = (
+        session.query(pagure.lib.model.PullRequestComment).filter(
+            pagure.lib.model.PullRequestComment.user_id == user.id
+        )
+    ).all()
+
+    groups = (
+        session.query(pagure.lib.model.PagureGroup).filter(
+            pagure.lib.model.PagureGroup.user_id == user.id
+        )
+    ).all()
+
+    blocked = bool(
+        pagure.lib.query.get_blocked_users(
+            session, username=user.user, date=None
+        )
+    )
+
+    print("# Projects")
+    if projects:
+        for project in projects:
+            print(f"* {project.full_url}")
+    else:
+        print("    ***User has no Projects***")
+
+    print("# Issues")
+    if issues:
+        for issue in issues:
+            print(f"* {issue.full_url}")
+    else:
+        print("    ***User has no Issues***")
+
+    print("# Blocked Status")
+    if blocked:
+        print("    ***User is already blocked***")
+    else:
+        print("    User is NOT blocked on pagure")
+
+    if issues or projects or not blocked:
+        print("\nAre you sure you want to:")
+        if projects:
+            print(f"* DELETE {len(projects)} projects")
+        if issues:
+            print(f"* DELETE {len(issues)} issues")
+        if not blocked:
+            print(f"* BLOCK {user.user} on pagure until 2099-01-01")
+
+        if not _ask_confirmation():
+            return
+
+        if issues:
+            for issue in issues:
+                print(f"DELETING ISSUE: {issue.full_url}")
+                pagure.lib.query.drop_issue(
+                    session,
+                    issue=issue,
+                    user=action_user.user,
+                )
+                session.commit()
+
+        if projects:
+            for project in projects:
+                print(f"DELETING PROJECT: {project.full_url}")
+                pagure.lib.tasks.delete_project(
+                    namespace=project.namespace,
+                    name=project.name,
+                    user=project.user.user if project.is_fork else None,
+                    action_user=action_user.user,
+                )
+                session.commit()
+
+        if not blocked:
+            # block the user
+            print(f"BLOCKING USER: {user.user} until 2099-01-01")
+            date = arrow.get("2099-01-01", "YYYY-MM-DD").replace(tzinfo="UTC")
+            user.refuse_sessions_before = date.datetime
+            session.add(user)
+            session.commit()
+
+    print(f"\n\n# Activity by {user.user} that needs to be removed manually:")
+
+    print("## Issue Comments")
+    if comments:
+        for comment in comments:
+            print(f"* {comment.issue.full_url}#comment-{comment.id}")
+    else:
+        print("    ***User has no Issue Comments***")
+    print("## Pull Requests")
+    if prs:
+        for pr in prs:
+            print(f"* {pr.full_url}")
+    else:
+        print("    ***User has no Pull Requests***")
+
+    print("## Pull Request Comments")
+    if prcomments:
+        for prcomment in prcomments:
+            print(
+                f"* {prcomment.pull_request.full_url}#comment-{prcomment.id}"
+            )
+    else:
+        print("    ***User has no Pull Request Comments***")
+
+    print("## Groups Created by the User")
+    if groups:
+        for group in groups:
+            print(f"* {group.full_url}")
+    else:
+        print("    ***User has not created any Groups***")
+
+
+def do_update_acls(args):
+    """Update the ACLs in the database from the list present in the
+    configuration file.
+
+    :arg args: the argparse object returned by ``parse_arguments()``.
+
+    """
+    acls = _config.get("ACLS", {})
+    _log.debug("ACLS:       %s", acls)
+
+    pagure.lib.model.create_default_status(session, acls=acls)
+    print(
+        "ACLS in the database synced with the list in the configuration file"
+    )
+
+
 def do_get_watch_status(args):
-    """ Get the watch status of an user on a project.
+    """Get the watch status of an user on a project.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -944,7 +1154,7 @@ def do_get_watch_status(args):
 
 
 def do_update_watch_status(args):
-    """ Update the watch status of an user on a project.
+    """Update the watch status of an user on a project.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -988,7 +1198,7 @@ def do_update_watch_status(args):
 
 
 def do_read_only(args):
-    """ Set or update the read-only status of a project.
+    """Set or update the read-only status of a project.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -1030,7 +1240,7 @@ def do_read_only(args):
 
 
 def do_new_group(args):
-    """ Create a new group in this pagure instance.
+    """Create a new group in this pagure instance.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -1075,7 +1285,7 @@ def do_new_group(args):
 
 
 def do_list_groups(args):
-    """ Lists existing groups in this pagure instance.
+    """Lists existing groups in this pagure instance.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -1091,7 +1301,7 @@ def do_list_groups(args):
 
 
 def do_list_blocked_users(args):
-    """ List all the blocked users.
+    """List all the blocked users.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
 
@@ -1126,7 +1336,7 @@ def do_list_blocked_users(args):
 
 
 def do_block_user(args):
-    """ Block the specified user from all interactions with pagure until the
+    """Block the specified user from all interactions with pagure until the
     specified date.
 
     :arg args: the argparse object returned by ``parse_arguments()``.
@@ -1170,7 +1380,7 @@ def do_block_user(args):
 
 
 def do_upload_repospanner_hooks(args):
-    """ Upload hooks to repoSpanner
+    """Upload hooks to repoSpanner
 
     Args:
         args (argparse.Namespace): Parsed arguments
@@ -1216,7 +1426,7 @@ def do_upload_repospanner_hooks(args):
 
 
 def do_ensure_project_hooks(args):
-    """ Ensures that all projects have their hooks setup
+    """Ensures that all projects have their hooks setup
 
     Args:
         args (argparse.Namespace): Parsed arguments
@@ -1235,7 +1445,7 @@ def do_ensure_project_hooks(args):
 
 
 def do_create_branch(args):
-    """ Creates the specified git branch
+    """Creates the specified git branch
 
     Args:
         args (argparse.Namespace): Parsed arguments
@@ -1286,7 +1496,7 @@ def do_create_branch(args):
 
 
 def do_set_default_branch(args):
-    """ Sets the specified git branch as default
+    """Sets the specified git branch as default
 
     Args:
         args (argparse.Namespace): Parsed arguments
