@@ -63,6 +63,13 @@ ENABLE_DOCS = True
 # Enables / Disables creating projects on this pagure instance
 ENABLE_NEW_PROJECTS = True
 
+# When using OIDC auth, users must be in this OIDC group to create new projects
+RESTRICT_CREATE_BY_OIDC_GROUP = None
+
+# When using OIDC auth, users must be a member of RESTRICT_NEW_PROJECTS_BY_OIDC_GROUP and in total
+# this many groups to create new projects
+RESTRICT_CREATE_BY_OIDC_GROUP_COUNT = 0
+
 # Enables / Disables deleting projects on this pagure instance
 ENABLE_DEL_PROJECTS = True
 
@@ -78,6 +85,9 @@ ENABLE_GROUP_MNGT = True
 # Enables / Disables private projects
 PRIVATE_PROJECTS = True
 
+# Enable / Disable user registration (local auth only)
+ALLOW_USER_REGISTRATION = True
+
 # Enable / Disable deleting branches in the UI
 ALLOW_DELETE_BRANCH = True
 
@@ -355,6 +365,10 @@ ACLS = {
     "pull_request_rebase": "Rebase a pull-request",
     "tag_project": "Allows adding git tags to a project",
     "commit": "Commit to a git repository via http(s)",
+    "modify_git_alias": "Modify git aliases (create or delete)",
+    "create_git_alias": "Create git aliases",
+    "delete_git_alias": "Delete git aliases",
+    "group_modify": "Add/Remove members from group",
 }
 
 # List of ACLs which a regular user is allowed to associate to an API token
@@ -371,8 +385,10 @@ CROSS_PROJECT_ACLS = [
     "create_project",
     "fork_project",
     "modify_project",
+    "group_modify",
     "update_watch_status",
     "pull_request_create",
+    "pull_request_update",
     "commit",
 ]
 
@@ -386,6 +402,7 @@ ADMIN_API_ACLS = [
     "pull_request_comment",
     "pull_request_merge",
     "generate_acls_project",
+    "group_modify",
     "commit_flag",
     "create_branch",
     "tag_project",
@@ -637,3 +654,17 @@ CSP_HEADERS = (
     "base-uri 'self';"
     "img-src 'self' https:;"
 )
+
+PR_WARN_CHARACTERS = set(
+    [
+        chr(0x202A),
+        chr(0x202B),
+        chr(0x202C),
+        chr(0x202D),
+        chr(0x202E),
+        chr(0x2066),
+        chr(0x2067),
+        chr(0x2068),
+        chr(0x2069),
+    ]
+)
