@@ -17,6 +17,7 @@ import string
 import time
 import os
 import warnings
+from six.moves.urllib.parse import urljoin
 
 import flask
 import pygit2
@@ -40,7 +41,6 @@ if os.environ.get("PAGURE_PERFREPO"):
 else:
     perfrepo = None
 
-
 logger = logging.getLogger(__name__)
 
 REDIS = None
@@ -50,8 +50,9 @@ if (
     or pagure_config.get("PAGURE_CI_SERVICES")
 ):
     pagure.lib.query.set_redis(
-        host=pagure_config["REDIS_HOST"],
-        port=pagure_config["REDIS_PORT"],
+        host=pagure_config.get("REDIS_HOST", None),
+        port=pagure_config.get("REDIS_PORT", None),
+        socket=pagure_config.get("REDIS_SOCKET", None),
         dbname=pagure_config["REDIS_DB"],
     )
 
@@ -210,8 +211,7 @@ def create_app(config=None):
 
 
 def generate_user_key_files():
-    """ Regenerate the key files used by gitolite.
-    """
+    """Regenerate the key files used by gitolite."""
     gitolite_home = pagure_config.get("GITOLITE_HOME", None)
     if gitolite_home:
         users = pagure.lib.query.search_user(flask.g.session)
@@ -227,7 +227,7 @@ def generate_user_key_files():
 
 
 def admin_session_timedout():
-    """ Check if the current user has been authenticated for more than what
+    """Check if the current user has been authenticated for more than what
     is allowed (defaults to 15 minutes).
     If it is the case, the user is logged out and the method returns True,
     otherwise it returns False.
@@ -248,8 +248,7 @@ def admin_session_timedout():
 
 
 def logout():
-    """ Log out the user currently logged in in the application
-    """
+    """Log out the user currently logged in in the application"""
     auth = pagure_config.get("PAGURE_AUTH", None)
     if auth in ["fas", "openid"]:
         if hasattr(flask.g, "fas_user") and flask.g.fas_user is not None:
@@ -446,7 +445,9 @@ def auth_login():  # pragma: no cover
     return_point = flask.url_for("ui_ns.index")
     if "next" in flask.request.args:
         if pagure.utils.is_safe_url(flask.request.args["next"]):
-            return_point = flask.request.args["next"]
+            return_point = urljoin(
+                flask.request.host_url, flask.request.args["next"]
+            )
 
     authenticated = pagure.utils.authenticated()
     auth = pagure_config.get("PAGURE_AUTH", None)
@@ -492,6 +493,8 @@ def auth_login():  # pragma: no cover
                 )
             ]
         groups = set(groups).union(admins)
+        if auth == "fas":
+            groups.add("signed_fpca")
         ext_committer = set(pagure_config.get("EXTERNAL_COMMITTER", {}))
         groups = set(groups).union(ext_committer)
         flask.g.unsafe_javascript = True
@@ -508,7 +511,9 @@ def auth_logout():  # pragma: no cover
     return_point = flask.url_for("ui_ns.index")
     if "next" in flask.request.args:
         if pagure.utils.is_safe_url(flask.request.args["next"]):
-            return_point = flask.request.args["next"]
+            return_point = urljoin(
+                flask.request.host_url, flask.request.args["next"]
+            )
 
     if not pagure.utils.authenticated():
         return flask.redirect(return_point)
@@ -521,7 +526,7 @@ def auth_logout():  # pragma: no cover
 
 # pylint: disable=unused-argument
 def end_request(exception=None):
-    """ This method is called at the end of each request.
+    """This method is called at the end of each request.
 
     Remove the DB session at the end of each request.
     Runs a garbage collection to get rid of any open pygit2 handles.
@@ -555,8 +560,7 @@ def after_request(response):
 
 
 def _get_user(username):
-    """ Check if user exists or not
-    """
+    """Check if user exists or not"""
     try:
         return pagure.lib.query.get_user(flask.g.session, username)
     except pagure.exceptions.PagureException as e:
