@@ -74,7 +74,7 @@ def convert_value(val):
 
 
 class MultipleEmail(wtforms.validators.Email):
-    """ Split the value by comma and run them through the email validator
+    """Split the value by comma and run them through the email validator
     of wtforms.
     """
 
@@ -87,15 +87,14 @@ class MultipleEmail(wtforms.validators.Email):
 
 
 def user_namespace_if_private(form, field):
-    """ Check if the data in the field is the same as in the password field.
-    """
+    """Check if the data in the field is the same as in the password field."""
     if form.private.data:
         field.data = flask.g.fas_user.username
 
 
 def file_virus_validator(form, field):
-    """ Checks for virus in the file from flask request object,
-    raises wtf.ValidationError if virus is found else None. """
+    """Checks for virus in the file from flask request object,
+    raises wtf.ValidationError if virus is found else None."""
 
     if not pagure_config["VIRUS_SCAN_ATTACHMENTS"]:
         return
@@ -136,7 +135,7 @@ class ProjectFormSimplified(PagureForm):
     """ Form to edit the description of a project. """
 
     description = wtforms.StringField(
-        'Description <span class="error">*</span>',
+        "Description",
         [wtforms.validators.DataRequired()],
     )
     url = wtforms.StringField(
@@ -169,7 +168,7 @@ class ProjectFormSimplified(PagureForm):
 class ProjectForm(ProjectFormSimplified):
     """ Form to create or edit project. """
 
-    name = wtforms.StringField('Project name <span class="error">*</span>')
+    name = wtforms.StringField("Project name")
     mirrored_from = wtforms.StringField(
         "Mirror from URL",
         [
@@ -207,11 +206,12 @@ class ProjectForm(ProjectFormSimplified):
         default=pagure_config["REPOSPANNER_NEW_REPO"],
     )
     default_branch = wtforms.StringField(
-        "Default branch", [wtforms.validators.optional()],
+        "Default branch",
+        [wtforms.validators.optional()],
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -252,11 +252,11 @@ class IssueFormSimplied(PagureForm):
     """ Form to create or edit an issue. """
 
     title = wtforms.StringField(
-        'Title<span class="error">*</span>',
+        "Title",
         [wtforms.validators.DataRequired()],
     )
     issue_content = wtforms.TextAreaField(
-        'Content<span class="error">*</span>',
+        "Content",
         [wtforms.validators.DataRequired()],
     )
     private = wtforms.BooleanField(
@@ -276,7 +276,7 @@ class IssueFormSimplied(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -302,7 +302,7 @@ class IssueForm(IssueFormSimplied):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -317,7 +317,7 @@ class RequestPullForm(PagureForm):
     """ Form to create a pull request. """
 
     title = wtforms.StringField(
-        'Title<span class="error">*</span>',
+        "Title",
         [wtforms.validators.DataRequired()],
     )
     initial_comment = wtforms.TextAreaField(
@@ -330,22 +330,44 @@ class RequestPullForm(PagureForm):
     )
 
 
+class RequestPullEditForm(RequestPullForm):
+    """ Form to edit a pull request. """
+
+    branch_to = wtforms.SelectField(
+        "Target branch",
+        [wtforms.validators.Required()],
+        choices=[],
+        coerce=convert_value,
+    )
+
+    def __init__(self, *args, **kwargs):
+        """Calls the default constructor with the normal argument but
+        uses the list of collection provided to fill the choices of the
+        drop-down list.
+        """
+        super(RequestPullEditForm, self).__init__(*args, **kwargs)
+        if "branches" in kwargs:
+            self.branch_to.choices = [
+                (branch, branch) for branch in kwargs["branches"]
+            ]
+
+
 class RemoteRequestPullForm(RequestPullForm):
     """ Form to create a remote pull request. """
 
     git_repo = wtforms.StringField(
-        'Git repo address<span class="error">*</span>',
+        "Git repo address",
         [
             wtforms.validators.DataRequired(),
             wtforms.validators.Regexp(urlpattern, flags=re.IGNORECASE),
         ],
     )
     branch_from = wtforms.StringField(
-        'Git branch<span class="error">*</span>',
+        "Git branch",
         [wtforms.validators.DataRequired()],
     )
     branch_to = wtforms.StringField(
-        'Git branch to merge in<span class="error">*</span>',
+        "Git branch to merge in",
         [wtforms.validators.DataRequired()],
     )
 
@@ -405,7 +427,7 @@ class StatusForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -432,7 +454,7 @@ class MilestoneForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -460,7 +482,7 @@ class NewTokenForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -517,7 +539,7 @@ class UpdateIssueForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -554,7 +576,7 @@ class AddPullRequestCommentForm(PagureForm):
     requestid = wtforms.HiddenField("requestid")
     tree_id = wtforms.HiddenField("treeid")
     comment = wtforms.TextAreaField(
-        'Comment<span class="error">*</span>',
+        "Comment",
         [wtforms.validators.DataRequired()],
     )
 
@@ -605,7 +627,7 @@ class AddSSHKeyForm(PagureForm):
     """ Form to add a SSH key to a user. """
 
     ssh_key = wtforms.StringField(
-        'SSH Key <span class="error">*</span>',
+        "SSH Key",
         [wtforms.validators.DataRequired()]
         # TODO: Add an ssh key validator?
     )
@@ -625,15 +647,15 @@ class AddUserForm(PagureForm):
     """ Form to add a user to a project. """
 
     user = wtforms.StringField(
-        'Username <span class="error">*</span>',
+        "Username",
         [wtforms.validators.DataRequired()],
     )
     access = wtforms.StringField(
-        'Access Level <span class="error">*</span>',
+        "Access Level",
         [wtforms.validators.DataRequired()],
     )
     branches = wtforms.StringField(
-        'Git branches <span class="error">*</span>',
+        "Git branches",
         [wtforms.validators.Optional()],
     )
 
@@ -642,7 +664,7 @@ class AddUserToGroupForm(PagureForm):
     """ Form to add a user to a pagure group. """
 
     user = wtforms.StringField(
-        'Username <span class="error">*</span>',
+        "Username",
         [wtforms.validators.DataRequired()],
     )
 
@@ -651,7 +673,7 @@ class AssignIssueForm(PagureForm):
     """ Form to assign an user to an issue. """
 
     assignee = wtforms.StringField(
-        'Assignee <span class="error">*</span>',
+        "Assignee",
         [wtforms.validators.Optional()],
     )
 
@@ -660,18 +682,18 @@ class AddGroupForm(PagureForm):
     """ Form to add a group to a project. """
 
     group = wtforms.StringField(
-        'Group <span class="error">*</span>',
+        "Group",
         [
             wtforms.validators.DataRequired(),
             wtforms.validators.Regexp(STRICT_REGEX, flags=re.IGNORECASE),
         ],
     )
     access = wtforms.StringField(
-        'Access Level <span class="error">*</span>',
+        "Access Level",
         [wtforms.validators.DataRequired()],
     )
     branches = wtforms.StringField(
-        'Git branches <span class="error">*</span>',
+        "Git branches",
         [wtforms.validators.Optional()],
     )
 
@@ -691,7 +713,7 @@ class ModifyACLForm(PagureForm):
         choices=[("user", "User"), ("group", "Group")],
     )
     name = wtforms.StringField(
-        'User- or Groupname <span class="error">*</span>',
+        "User- or Groupname",
         [wtforms.validators.DataRequired()],
     )
     acl = wtforms.SelectField(
@@ -773,7 +795,7 @@ class NewGroupForm(EditGroupForm):
     """ Form to ask for a password change. """
 
     group_name = wtforms.StringField(
-        'Group name  <span class="error">*</span>',
+        "Group name",
         [
             wtforms.validators.DataRequired(),
             wtforms.validators.Length(max=255),
@@ -785,7 +807,7 @@ class NewGroupForm(EditGroupForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -812,7 +834,7 @@ class EditFileForm(PagureForm):
     branch = wtforms.StringField("Branch", [wtforms.validators.DataRequired()])
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -831,7 +853,7 @@ class DefaultBranchForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -850,7 +872,7 @@ class DefaultPriorityForm(PagureForm):
     )
 
     def __init__(self, *args, **kwargs):
-        """ Calls the default constructor with the normal argument but
+        """Calls the default constructor with the normal argument but
         uses the list of collection provided to fill the choices of the
         drop-down list.
         """
@@ -862,11 +884,10 @@ class DefaultPriorityForm(PagureForm):
 
 
 class EditCommentForm(PagureForm):
-    """ Form to verify that comment is not empty
-    """
+    """Form to verify that comment is not empty"""
 
     update_comment = wtforms.TextAreaField(
-        'Comment<span class="error">*</span>',
+        "Comment ",
         [wtforms.validators.DataRequired()],
     )
 
@@ -886,26 +907,24 @@ class ForkRepoForm(PagureForm):
 
 
 class AddReportForm(PagureForm):
-    """ Form to verify that comment is not empty
-    """
+    """Form to verify that comment is not empty"""
 
     report_name = wtforms.TextAreaField(
-        'Report name<span class="error">*</span>',
+        "Report name",
         [wtforms.validators.DataRequired()],
     )
 
 
 class PublicNotificationForm(PagureForm):
-    """ Form to verify that comment is not empty
-    """
+    """Form to verify that comment is not empty"""
 
     issue_notifs = wtforms.TextAreaField(
-        'Public issue notification<span class="error">*</span>',
+        "Public issue notification",
         [wtforms.validators.optional(), MultipleEmail()],
     )
 
     pr_notifs = wtforms.TextAreaField(
-        'Public PR notification<span class="error">*</span>',
+        "Public PR notification",
         [wtforms.validators.optional(), MultipleEmail()],
     )
 
@@ -953,7 +972,7 @@ class AddGitTagForm(PagureForm):
     """ Form to create a new git tag. """
 
     tagname = wtforms.StringField(
-        'Name of the tag<span class="error">*</span>',
+        "Name of the tag",
         [wtforms.validators.DataRequired()],
     )
     commit_hash = wtforms.StringField(
