@@ -27,7 +27,7 @@ from pagure.lib.plugins import get_enabled_plugins
 
 
 class RequiredIf(wtforms.validators.DataRequired):
-    """ Wtforms validator setting a field as required if another field
+    """Wtforms validator setting a field as required if another field
     has a value.
     """
 
@@ -62,9 +62,17 @@ class BaseRunner(object):
 
     @classmethod
     def runhook(
-        cls, session, username, hooktype, project, repotype, repodir, changes
+        cls,
+        session,
+        username,
+        hooktype,
+        project,
+        repotype,
+        repodir,
+        changes,
+        pull_request,
     ):
-        """ Run a specific hook on a project.
+        """Run a specific hook on a project.
 
         By default, this calls out to the pre_receive, update or post_receive
         functions as appropriate.
@@ -81,6 +89,8 @@ class BaseRunner(object):
             changes (dict): A dict with keys being the ref to update, values
                 being a tuple of (from, to).
                 For example: {'refs/heads/master': (hash_from, hash_to), ...}
+            pull_request (model.PullRequest or None): The pull request whose
+                merge is initiating this hook run.
         """
         if hooktype == "pre-receive":
             cls.pre_receive(
@@ -90,6 +100,7 @@ class BaseRunner(object):
                 repotype=repotype,
                 repodir=repodir,
                 changes=changes,
+                pull_request=pull_request,
             )
         elif hooktype == "update":
             cls.update(
@@ -99,6 +110,7 @@ class BaseRunner(object):
                 repotype=repotype,
                 repodir=repodir,
                 changes=changes,
+                pull_request=pull_request,
             )
 
         elif hooktype == "post-receive":
@@ -109,21 +121,26 @@ class BaseRunner(object):
                 repotype=repotype,
                 repodir=repodir,
                 changes=changes,
+                pull_request=pull_request,
             )
         else:
             raise ValueError('Invalid hook type "%s"' % hooktype)
 
     @staticmethod
-    def pre_receive(session, username, project, repotype, repodir, changes):
-        """ Run the pre-receive tasks of a hook.
+    def pre_receive(
+        session, username, project, repotype, repodir, changes, pull_request
+    ):
+        """Run the pre-receive tasks of a hook.
 
         For args, see BaseRunner.runhook.
         """
         pass
 
     @staticmethod
-    def update(session, username, project, repotype, repodir, changes):
-        """ Run the update tasks of a hook.
+    def update(
+        session, username, project, repotype, repodir, changes, pull_request
+    ):
+        """Run the update tasks of a hook.
 
         For args, see BaseRunner.runhook.
         Note that the "changes" list has exactly one element.
@@ -131,8 +148,10 @@ class BaseRunner(object):
         pass
 
     @staticmethod
-    def post_receive(session, username, project, repotype, repodir, changes):
-        """ Run the post-receive tasks of a hook.
+    def post_receive(
+        session, username, project, repotype, repodir, changes, pull_request
+    ):
+        """Run the post-receive tasks of a hook.
 
         For args, see BaseRunner.runhook.
         """
@@ -154,7 +173,7 @@ class BaseHook(object):
 
     @classmethod
     def set_up(cls, project):
-        """ Install the generic post-receive hook that allow us to call
+        """Install the generic post-receive hook that allow us to call
         multiple post-receive hooks as set per plugin.
         """
         if project.is_on_repospanner:
@@ -186,7 +205,7 @@ class BaseHook(object):
 
     @classmethod
     def base_install(cls, repopaths, dbobj, hook_name, filein):
-        """ Method called to install the hook for a project.
+        """Method called to install the hook for a project.
 
         :arg project: a ``pagure.model.Project`` object to which the hook
             should be installed
@@ -222,7 +241,7 @@ class BaseHook(object):
 
     @classmethod
     def base_remove(cls, repopaths, hook_name):
-        """ Method called to remove the hook of a project.
+        """Method called to remove the hook of a project.
 
         :arg project: a ``pagure.model.Project`` object to which the hook
             should be installed
@@ -240,7 +259,7 @@ class BaseHook(object):
 
     @classmethod
     def install(cls, *args):
-        """ In sub-classess, this can be used for installation of the hook.
+        """In sub-classess, this can be used for installation of the hook.
 
         However, this is not required anymore for hooks with a Runner.
         This class is here as backwards compatibility.
@@ -252,7 +271,7 @@ class BaseHook(object):
 
     @classmethod
     def remove(cls, *args):
-        """ In sub-classess, this can be used for removal of the hook.
+        """In sub-classess, this can be used for removal of the hook.
 
         However, this is not required anymore for hooks with a Runner.
         This class is here as backwards compatibility.
@@ -264,7 +283,7 @@ class BaseHook(object):
 
     @classmethod
     def is_enabled_for(cls, project):
-        """ Determine if this hook should be run for given project.
+        """Determine if this hook should be run for given project.
 
         On some Pagure instances, some hooks should be run on all projects
         that fulfill certain criteria. It is therefore not necessary to keep
@@ -294,7 +313,7 @@ def run_project_hooks(
     is_internal,
     pull_request,
 ):
-    """ Function to run the hooks on a project
+    """Function to run the hooks on a project
 
     This will first call all the plugins with a Runner on the project,
     and afterwards, for a non-repoSpanner repo, run all hooks/<hooktype>.*
@@ -390,6 +409,7 @@ def run_project_hooks(
                     repotype=repotype,
                     repodir=repodir,
                     changes=changes,
+                    pull_request=pull_request,
                 )
             except Exception as e:
                 if hooktype != "pre-receive" or debug:
@@ -470,7 +490,7 @@ def run_project_hooks(
 
 
 def extract_changes(from_stdin):
-    """ Extracts a changes dict from either stdin or argv
+    """Extracts a changes dict from either stdin or argv
 
     Args:
         from_stdin (bool): Whether to use stdin. If false, uses argv
@@ -491,12 +511,15 @@ def extract_changes(from_stdin):
 
 
 def run_hook_file(hooktype):
-    """ Runs a specific hook by grabbing the changes and running functions.
+    """Runs a specific hook by grabbing the changes and running functions.
 
     Args:
         hooktype (string): The name of the hook to run: pre-receive, update
             or post-receive
     """
+    if pagure_config.get("NOGITHOOKS") or False:
+        return
+
     if hooktype not in ("pre-receive", "update", "post-receive"):
         raise ValueError("Hook type %s not valid" % hooktype)
     changes = extract_changes(from_stdin=hooktype != "update")
