@@ -35,6 +35,7 @@ import pagure.lib.query
 import pagure.lib.tasks_services
 from pagure.config import config as pagure_config
 from pagure.pfmarkdown import MENTION_RE
+from markdown.extensions.fenced_code import FencedBlockPreprocessor
 
 
 _log = logging.getLogger(__name__)
@@ -79,13 +80,28 @@ def fedora_messaging_publish(topic, message):  # pragma: no cover
     try:
         import fedora_messaging.api
         import fedora_messaging.exceptions
+        import pagure_messages
 
-        msg = fedora_messaging.api.Message(
-            topic="pagure.{}".format(topic), body=message
+        msg_cls = pagure_messages.get_message_object_from_topic(
+            "pagure.{}".format(topic)
         )
+
+        if not hasattr(msg_cls, "app_name") is False:
+            _log.warning(
+                "pagure is about to send a message that has no schemas: "
+                "pagure.%s",
+                topic,
+            )
+
+        msg = msg_cls(body=message)
+        if not msg.topic:
+            msg.topic = "pagure.{}".format(topic)
         fedora_messaging.api.publish(msg)
     except ImportError:
-        _log.warning("Fedora messaging does not appear to be available")
+        _log.warning(
+            "Fedora messaging or pagure-messages does not appear to be "
+            "available"
+        )
     except fedora_messaging.exceptions.PublishReturned as e:
         _log.warning(
             "Fedora Messaging broker rejected message %s: %s", msg.id, e
@@ -145,7 +161,7 @@ def mqtt_publish(topic, message):
         return
 
     mqtt_host = pagure_config.get("MQTT_HOST")
-    mqtt_port = pagure_config.get("MQTT_PORT")
+    mqtt_port = int(pagure_config.get("MQTT_PORT"))
 
     mqtt_username = pagure_config.get("MQTT_USERNAME")
     mqtt_pass = pagure_config.get("MQTT_PASSWORD")
@@ -191,7 +207,7 @@ def mqtt_publish(topic, message):
 
 
 def log(project, topic, msg, webhook=True):
-    """ This is the place where we send notifications to user about actions
+    """This is the place where we send notifications to user about actions
     occuring in pagure.
     """
 
@@ -231,10 +247,13 @@ def log(project, topic, msg, webhook=True):
 
 
 def _add_mentioned_users(emails, comment):
-    """ Check the comment to see if an user is mentioned in it and if
+    """Check the comment to see if an user is mentioned in it and if
     so add this user to the list of people to notify.
     """
-    for username in re.findall(MENTION_RE, comment):
+    filtered_comment = re.sub(
+        FencedBlockPreprocessor.FENCED_BLOCK_RE, "", comment
+    )
+    for username in re.findall(MENTION_RE, filtered_comment):
         user = pagure.lib.query.search_user(flask.g.session, username=username)
         if user:
             emails.add(user.default_email)
@@ -242,7 +261,7 @@ def _add_mentioned_users(emails, comment):
 
 
 def _clean_emails(emails, user):
-    """ Remove the email of the user doing the action if it is in the list.
+    """Remove the email of the user doing the action if it is in the list.
 
     This avoids receiving emails about action you do.
     """
@@ -260,7 +279,7 @@ def _clean_emails(emails, user):
 
 
 def _get_emails_for_obj(obj):
-    """ Return the list of emails to send notification to when notifying
+    """Return the list of emails to send notification to when notifying
     about the specified issue or pull-request.
     """
     emails = set()
@@ -372,7 +391,7 @@ def _build_url(*args):
 
 
 def _fullname_to_url(fullname):
-    """ For forked projects, fullname is 'forks/user/...' but URL is
+    """For forked projects, fullname is 'forks/user/...' but URL is
     'fork/user/...'. This is why we can't have nice things.
     """
     if fullname.startswith("forks/"):
@@ -391,7 +410,7 @@ def send_email(
     reporter=None,
     assignee=None,
 ):  # pragma: no cover
-    """ Send an email with the specified information.
+    """Send an email with the specified information.
 
     :arg text: the content of the email to send
     :type text: unicode
@@ -511,7 +530,9 @@ def send_email(
                 keyfile = pagure_config.get("SMTP_KEYFILE") or None
                 certfile = pagure_config.get("SMTP_CERTFILE") or None
                 respcode, _ = smtp.starttls(
-                    keyfile=keyfile, certfile=certfile, context=context,
+                    keyfile=keyfile,
+                    certfile=certfile,
+                    context=context,
                 )
                 if respcode != 220:
                     _log.warning(
@@ -537,7 +558,7 @@ def send_email(
 
 
 def notify_new_comment(comment, user=None):
-    """ Notify the people following an issue that a new comment was added
+    """Notify the people following an issue that a new comment was added
     to the issue.
     """
 
@@ -583,7 +604,7 @@ def notify_new_comment(comment, user=None):
 
 
 def notify_new_issue(issue, user=None):
-    """ Notify the people following a project that a new issue was added
+    """Notify the people following a project that a new issue was added
     to it.
     """
     text = """
@@ -625,8 +646,7 @@ def notify_new_issue(issue, user=None):
 
 
 def notify_assigned_issue(issue, new_assignee, user):
-    """ Notify the people following an issue that the assignee changed.
-    """
+    """Notify the people following an issue that the assignee changed."""
     action = "reset"
     if new_assignee:
         action = "assigned to `%s`" % new_assignee.user
@@ -670,8 +690,7 @@ The issue: `%s` of project: `%s` has been %s by %s.
 
 
 def notify_status_change_issue(issue, user):
-    """ Notify the people following a project that an issue changed status.
-    """
+    """Notify the people following a project that an issue changed status."""
     status = issue.status
     if status.lower() != "open" and issue.close_status:
         status = "%s as %s" % (status, issue.close_status)
@@ -711,8 +730,7 @@ The status of the issue: `%s` of project: `%s` has been updated to: %s by %s.
 
 
 def notify_meta_change_issue(issue, user, msg):
-    """ Notify that a custom field changed
-    """
+    """Notify that a custom field changed"""
     text = """
 `%s` updated issue.
 
@@ -748,8 +766,7 @@ def notify_meta_change_issue(issue, user, msg):
 
 
 def notify_assigned_request(request, new_assignee, user):
-    """ Notify the people following a pull-request that the assignee changed.
-    """
+    """Notify the people following a pull-request that the assignee changed."""
     action = "reset"
     if new_assignee:
         action = "assigned to `%s`" % new_assignee.user
@@ -793,7 +810,7 @@ The pull-request: `%s` of project: `%s` has been %s by %s.
 
 
 def notify_new_pull_request(request):
-    """ Notify the people following a project that a new pull-request was
+    """Notify the people following a project that a new pull-request was
     added to it.
     """
     text = """
@@ -833,7 +850,7 @@ def notify_new_pull_request(request):
 
 
 def notify_merge_pull_request(request, user):
-    """ Notify the people following a project that a pull-request was merged
+    """Notify the people following a project that a pull-request was merged
     in it.
     """
     text = """
@@ -877,7 +894,7 @@ Merged pull-request:
 
 
 def notify_reopen_pull_request(request, user):
-    """ Notify the people following a project that a closed pull-request
+    """Notify the people following a project that a closed pull-request
     has been reopened.
     """
     text = """
@@ -921,7 +938,7 @@ Reopened pull-request:
 
 
 def notify_closed_pull_request(request, user):
-    """ Notify the people following a project that a pull-request was
+    """Notify the people following a project that a pull-request was
     closed in it.
     """
     text = """
@@ -966,7 +983,7 @@ Closed pull-request:
 
 
 def notify_pull_request_comment(comment, user):
-    """ Notify the people following a pull-request that a new comment was
+    """Notify the people following a pull-request that a new comment was
     added to it.
     """
     text = """
@@ -1012,8 +1029,8 @@ def notify_pull_request_comment(comment, user):
     )
 
 
-def notify_pull_request_flag(flag, user):
-    """ Notify the people following a pull-request that a new flag was
+def notify_pull_request_flag(flag, request, user):
+    """Notify the people following a pull-request that a new flag was
     added to it.
     """
     text = """
@@ -1022,38 +1039,35 @@ def notify_pull_request_flag(flag, user):
 %s
 """ % (
         flag.username,
-        flag.pull_request.title,
+        request.title,
         flag.status,
         flag.comment,
         _build_url(
             pagure_config["APP_URL"],
-            _fullname_to_url(flag.pull_request.project.fullname),
+            _fullname_to_url(request.project.fullname),
             "pull-request",
-            flag.pull_request.id,
+            request.id,
         ),
     )
-    mail_to = _get_emails_for_obj(flag.pull_request)
+    mail_to = _get_emails_for_obj(request)
 
-    assignee = (
-        flag.pull_request.assignee.user if flag.pull_request.assignee else None
-    )
+    assignee = request.assignee.user if request.assignee else None
 
     send_email(
         text,
-        "PR #%s - %s: %s" % (flag.pull_request.id, flag.username, flag.status),
+        "PR #%s - %s: %s" % (request.id, flag.username, flag.status),
         ",".join(mail_to),
         mail_id=flag.mail_id,
-        in_reply_to=flag.pull_request.mail_id,
-        project_name=flag.pull_request.project.fullname,
+        in_reply_to=request.mail_id,
+        project_name=request.project.fullname,
         user_from=flag.username,
-        reporter=flag.pull_request.user.user,
+        reporter=request.user.user,
         assignee=assignee,
     )
 
 
 def notify_new_email(email, user):
-    """ Ask the user to confirm to the email belong to them.
-    """
+    """Ask the user to confirm to the email belong to them."""
 
     root_url = pagure_config.get("APP_URL", flask.request.url_root)
 
@@ -1087,7 +1101,7 @@ Your pagure admin.
 
 
 def notify_new_commits(abspath, project, branch, commits):
-    """ Notify the people following a project's commits that new commits have
+    """Notify the people following a project's commits that new commits have
     been added.
     """
     # string note: abspath, project and branch can only contain ASCII
@@ -1144,7 +1158,7 @@ To view more about the commits, visit:
 
 
 def notify_commit_flag(flag, user):
-    """ Notify the people following a project that a new flag was added
+    """Notify the people following a project that a new flag was added
     to one of its commit.
     """
     text = """
