@@ -11,6 +11,7 @@
 from __future__ import unicode_literals, absolute_import
 
 import base64
+import datetime
 import logging
 import os
 import stat
@@ -38,8 +39,17 @@ if os.environ.get("PAGURE_BROKER_URL"):  # pragma: no-cover
     broker_url = os.environ["PAGURE_BROKER_URL"]
 elif pagure_config.get("BROKER_URL"):
     broker_url = pagure_config["BROKER_URL"]
-else:
-    broker_url = "redis://%s" % pagure_config["REDIS_HOST"]
+elif pagure_config.get("REDIS_SOCKET"):
+    broker_url = "redis+socket://%s?virtual_host=%d" % (
+        pagure_config["REDIS_SOCKET"],
+        pagure_config["REDIS_DB"],
+    )
+elif "REDIS_HOST" in pagure_config and "REDIS_PORT" in pagure_config:
+    broker_url = "redis://%s:%d/%d" % (
+        pagure_config["REDIS_HOST"],
+        pagure_config["REDIS_PORT"],
+        pagure_config["REDIS_DB"],
+    )
 
 conn = Celery("tasks_mirror", broker=broker_url, backend=broker_url)
 conn.conf.update(pagure_config["CELERY_CONFIG"])
@@ -78,7 +88,7 @@ def _serialize_public_ssh_key(key):
 
 
 def _create_ssh_key(keyfile):
-    """ Create the public and private ssh keys.
+    """Create the public and private ssh keys.
 
     The specified file name will be the private key and the public one will
     be in a similar file name ending with a '.pub'.
@@ -108,8 +118,7 @@ def _create_ssh_key(keyfile):
 @conn.task(queue=pagure_config["MIRRORING_QUEUE"], bind=True)
 @pagure_task
 def setup_mirroring(self, session, username, namespace, name):
-    """ Setup the specified project for mirroring.
-    """
+    """Setup the specified project for mirroring."""
     plugin = pagure.lib.plugins.get_plugin("Mirroring")
     plugin.db_object()
 
@@ -162,8 +171,7 @@ def setup_mirroring(self, session, username, namespace, name):
 @conn.task(queue=pagure_config["MIRRORING_QUEUE"], bind=True)
 @pagure_task
 def teardown_mirroring(self, session, username, namespace, name):
-    """ Stop the mirroring of the specified project.
-    """
+    """Stop the mirroring of the specified project."""
     plugin = pagure.lib.plugins.get_plugin("Mirroring")
     plugin.db_object()
 
@@ -191,8 +199,7 @@ def teardown_mirroring(self, session, username, namespace, name):
 @conn.task(queue=pagure_config["MIRRORING_QUEUE"], bind=True)
 @pagure_task
 def mirror_project(self, session, username, namespace, name):
-    """ Does the actual mirroring of the specified project.
-    """
+    """Does the actual mirroring of the specified project."""
     plugin = pagure.lib.plugins.get_plugin("Mirroring")
     plugin.db_object()
 
@@ -242,7 +249,8 @@ def mirror_project(self, session, username, namespace, name):
             error=True,
             env={"SSHKEY": private_key_file, "GIT_SSH": script_file},
         )
-        log = "Output from the push:\n  stdout: %s\n  stderr: %s" % (
+        log = "Output from the push (%s):\n  stdout: %s\n  stderr: %s" % (
+            datetime.datetime.utcnow().isoformat(),
             stdout,
             stderr,
         )
