@@ -63,6 +63,7 @@ def set_up_board(self):
             "boards": [
                 {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [],
                     "tag": {
@@ -263,6 +264,7 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
                 "boards": [
                     {
                         "active": True,
+                        "full_url": "http://localhost.localdomain/test/boards/dev",
                         "name": "dev",
                         "status": [],
                         "tag": {
@@ -299,6 +301,7 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
                 "boards": [
                     {
                         "active": True,
+                        "full_url": "http://localhost.localdomain/test/boards/dev",
                         "name": "dev",
                         "status": [],
                         "tag": {
@@ -309,6 +312,7 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
                     },
                     {
                         "active": True,
+                        "full_url": "http://localhost.localdomain/test/boards/infra",
                         "name": "infra",
                         "status": [],
                         "tag": {
@@ -322,7 +326,11 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
         )
 
         # Remove one of the 2 boards
-        data = json.dumps({"dev": {"active": True, "tag": "dev"},})
+        data = json.dumps(
+            {
+                "dev": {"active": True, "tag": "dev"},
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards", headers=headers, data=data
         )
@@ -334,6 +342,7 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
                 "boards": [
                     {
                         "active": True,
+                        "full_url": "http://localhost.localdomain/test/boards/dev",
                         "name": "dev",
                         "status": [],
                         "tag": {
@@ -390,7 +399,7 @@ class PagureFlaskApiBoardstests(tests.SimplePagureTest):
 
 
 class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
-    """ Tests for flask API Boards controller of pagure for the tests
+    """Tests for flask API Boards controller of pagure for the tests
     requiring a pre-existing board.
     """
 
@@ -422,6 +431,7 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
                 "boards": [
                     {
                         "active": False,
+                        "full_url": "http://localhost.localdomain/test/boards/dev",
                         "name": "dev",
                         "status": [],
                         "tag": {
@@ -441,7 +451,11 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
         }
 
         # Associate the existing board with an invalid tag
-        data = json.dumps({"dev": {"active": True, "tag": "invalid"},})
+        data = json.dumps(
+            {
+                "dev": {"active": True, "tag": "invalid"},
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards", headers=headers, data=data
         )
@@ -515,7 +529,8 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
         self.assertDictEqual(
-            data, {"boards": []},
+            data,
+            {"boards": []},
         )
 
     def test_api_board_delete_html_input(self):
@@ -531,7 +546,8 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
         self.assertDictEqual(
-            data, {"boards": []},
+            data,
+            {"boards": []},
         )
 
     def test_api_board_api_board_status_no_data(self):
@@ -768,6 +784,7 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
             {
                 "board": {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [
                         {
@@ -801,6 +818,88 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
             },
         )
 
+    def test_api_board_api_board_status_no_close_status(self):
+        headers = {
+            "Authorization": "token aaabbbcccddd",
+            "Content-Type": "application/json",
+        }
+
+        data = json.dumps(
+            {
+                "Backlog": {
+                    "close": False,
+                    "close_status": None,
+                    "bg_color": "#FFB300",
+                    "default": True,
+                    "rank": 1,
+                },
+                "Triaged": {
+                    "close": False,
+                    "close_status": None,
+                    "bg_color": "#ca0dcd",
+                    "default": False,
+                    "rank": 2,
+                },
+                "Done": {
+                    "close": True,
+                    "close_status": None,
+                    "bg_color": "#34d240",
+                    "default": False,
+                    "rank": 4,
+                },
+                "  ": {
+                    "close": True,
+                    "close_status": None,
+                    "bg_color": "#34d240",
+                    "default": False,
+                    "rank": 5,
+                },
+            }
+        )
+        output = self.app.post(
+            "/api/0/test/boards/dev/status", headers=headers, data=data
+        )
+        self.assertEqual(output.status_code, 200)
+        data = json.loads(output.get_data(as_text=True))
+        self.assertDictEqual(
+            data,
+            {
+                "board": {
+                    "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
+                    "name": "dev",
+                    "status": [
+                        {
+                            "bg_color": "#FFB300",
+                            "close": False,
+                            "close_status": None,
+                            "default": True,
+                            "name": "Backlog",
+                        },
+                        {
+                            "bg_color": "#ca0dcd",
+                            "close": False,
+                            "close_status": None,
+                            "default": False,
+                            "name": "Triaged",
+                        },
+                        {
+                            "name": "Done",
+                            "close": True,
+                            "close_status": None,
+                            "default": False,
+                            "bg_color": "#34d240",
+                        },
+                    ],
+                    "tag": {
+                        "tag": "dev",
+                        "tag_color": "DeepBlueSky",
+                        "tag_description": "",
+                    },
+                }
+            },
+        )
+
     def test_api_board_api_board_status_adding_removing(self):
         headers = {
             "Authorization": "token aaabbbcccddd",
@@ -849,6 +948,7 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
             {
                 "board": {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [
                         {
@@ -917,6 +1017,7 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
             {
                 "board": {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [
                         {
@@ -952,7 +1053,7 @@ class PagureFlaskApiBoardsWithBoardtests(tests.SimplePagureTest):
 
 
 class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
-    """ Tests for flask API Boards controller of pagure for the tests
+    """Tests for flask API Boards controller of pagure for the tests
     requiring a pre-existing board and issues.
     """
 
@@ -1039,7 +1140,14 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "Content-Type": "application/json",
         }
 
-        data = json.dumps({"12": {"status": "In Progress", "rank": 2,}})
+        data = json.dumps(
+            {
+                "12": {
+                    "status": "In Progress",
+                    "rank": 2,
+                }
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards/invalid/add_issue", headers=headers, data=data
         )
@@ -1102,7 +1210,13 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "Content-Type": "application/json",
         }
 
-        data = json.dumps({"12": {"rank": 2,}})
+        data = json.dumps(
+            {
+                "12": {
+                    "rank": 2,
+                }
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards/dev/add_issue", headers=headers, data=data
         )
@@ -1159,6 +1273,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             {
                 "board": {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [
                         {
@@ -1198,7 +1313,14 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "Content-Type": "application/json",
         }
 
-        data = json.dumps({"12": {"status": "In Progress", "rank": 2,}})
+        data = json.dumps(
+            {
+                "12": {
+                    "status": "In Progress",
+                    "rank": 2,
+                }
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards/invalid/update_issue",
             headers=headers,
@@ -1263,7 +1385,13 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "Content-Type": "application/json",
         }
 
-        data = json.dumps({"12": {"rank": 2,}})
+        data = json.dumps(
+            {
+                "12": {
+                    "rank": 2,
+                }
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards/dev/add_issue", headers=headers, data=data
         )
@@ -1320,6 +1448,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             {
                 "board": {
                     "active": True,
+                    "full_url": "http://localhost.localdomain/test/boards/dev",
                     "name": "dev",
                     "status": [
                         {
@@ -1360,7 +1489,9 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
         }
 
         data = json.dumps(
-            {self.tickets_uid[1]: {"status": "Done", "rank": 2},}
+            {
+                self.tickets_uid[1]: {"status": "Done", "rank": 2},
+            }
         )
         output = self.app.post(
             "/api/0/test/boards/dev/update_issue", headers=headers, data=data
@@ -1374,7 +1505,9 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
         self.assertEqual(repo.issues[1].close_status, "Fixed")
 
         data = json.dumps(
-            {self.tickets_uid[1]: {"status": "In Progress", "rank": 2},}
+            {
+                self.tickets_uid[1]: {"status": "In Progress", "rank": 2},
+            }
         )
         output = self.app.post(
             "/api/0/test/boards/dev/update_issue", headers=headers, data=data
@@ -1395,7 +1528,11 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "Content-Type": "application/json",
         }
 
-        data = json.dumps({"2": {"status": "In Progress", "rank": 2},})
+        data = json.dumps(
+            {
+                "2": {"status": "In Progress", "rank": 2},
+            }
+        )
         output = self.app.post(
             "/api/0/test/boards/dev/add_issue", headers=headers, data=data
         )
@@ -1419,6 +1556,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
                 {
                     "board": {
                         "active": True,
+                        "full_url": "http://localhost.localdomain/test/boards/dev",
                         "name": "dev",
                         "status": [
                             {
@@ -1475,6 +1613,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
                     "user": {
                         "default_email": "bar@pingou.com",
                         "emails": ["bar@pingou.com", "foo@pingou.com"],
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "fullname": "PY C",
                         "name": "pingou",
                         "url_path": "user/pingou",
@@ -1485,6 +1624,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "custom_fields": [],
             "date_created": "1594654596",
             "depends": [],
+            "full_url": "http://localhost.localdomain/test/issue/2",
             "id": 2,
             "last_updated": "1594654596",
             "milestone": None,
@@ -1497,6 +1637,7 @@ class PagureFlaskApiBoardsWithBoardAndIssuetests(tests.SimplePagureTest):
             "user": {
                 "default_email": "foo@bar.com",
                 "emails": ["foo@bar.com"],
+                "full_url": "http://localhost.localdomain/user/foo",
                 "fullname": "foo bar",
                 "name": "foo",
                 "url_path": "user/foo",
