@@ -101,8 +101,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         self.assertEqual(output.status_code, 200)
 
     def test_api_pull_request_update_invalid_project_namespace(self):
-        """ Test api_pull_request_update method when the project doesn't exist.
-        """
+        """Test api_pull_request_update method when the project doesn't exist."""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -123,8 +122,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_invalid_project(self):
-        """ Test api_pull_request_update method when the project doesn't exist.
-        """
+        """Test api_pull_request_update method when the project doesn't exist."""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -137,7 +135,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_invalid_project_token(self):
-        """ Test api_pull_request_update method when the token doesn't correspond
+        """Test api_pull_request_update method when the token doesn't correspond
         to the project.
         """
 
@@ -154,8 +152,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_invalid_pr(self):
-        """ Test api_assign_pull_request method when asking for an invalid PR
-        """
+        """Test api_assign_pull_request method when asking for an invalid PR"""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -168,8 +165,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_no_input(self):
-        """ Test api_assign_pull_request method when no input is specified
-        """
+        """Test api_assign_pull_request method when no input is specified"""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -187,8 +183,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_insufficient_input(self):
-        """ Test api_assign_pull_request method when no input is specified
-        """
+        """Test api_assign_pull_request method when no input is specified"""
 
         headers = {"Authorization": "token aaabbbcccddd"}
         data = {"initial_comment": "will not work"}
@@ -209,8 +204,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_edited(self):
-        """ Test api_assign_pull_request method when with valid input
-        """
+        """Test api_assign_pull_request method when with valid input"""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -252,6 +246,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "commit_start": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "commit_stop": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "date_created": "1551276260",
+                "full_url": "http://localhost.localdomain/test/pull-request/1",
                 "id": 1,
                 "initial_comment": "Edited initial comment",
                 "last_updated": "1551276261",
@@ -279,6 +274,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/test",
                     "fullname": "test",
                     "id": 1,
                     "milestones": {},
@@ -290,6 +286,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -314,6 +311,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/fork/pingou/test",
                     "fullname": "forks/pingou/test",
                     "id": 4,
                     "milestones": {},
@@ -343,6 +341,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "date_created": "1551276259",
                         "date_modified": "1551276259",
                         "description": "test project #1",
+                        "full_url": "http://localhost.localdomain/test",
                         "fullname": "test",
                         "id": 1,
                         "milestones": {},
@@ -354,6 +353,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "url_path": "test",
                         "user": {
                             "fullname": "PY C",
+                            "full_url": "http://localhost.localdomain/user/pingou",
                             "name": "pingou",
                             "url_path": "user/pingou",
                         },
@@ -363,6 +363,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "fork/pingou/test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -375,6 +376,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "updated_on": "1551276260",
                 "user": {
                     "fullname": "PY C",
+                    "full_url": "http://localhost.localdomain/user/pingou",
                     "name": "pingou",
                     "url_path": "user/pingou",
                 },
@@ -382,8 +384,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_edited_no_comment(self):
-        """ Test api_assign_pull_request method when with valid input
-        """
+        """Test api_assign_pull_request method when with valid input"""
 
         headers = {"Authorization": "token aaabbbcccddd"}
 
@@ -422,6 +423,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "commit_start": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "commit_stop": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "date_created": "1551276260",
+                "full_url": "http://localhost.localdomain/test/pull-request/1",
                 "id": 1,
                 "initial_comment": "",
                 "last_updated": "1551276261",
@@ -449,6 +451,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/test",
                     "fullname": "test",
                     "id": 1,
                     "milestones": {},
@@ -460,6 +463,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -484,6 +488,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/fork/pingou/test",
                     "fullname": "forks/pingou/test",
                     "id": 4,
                     "milestones": {},
@@ -513,6 +518,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "date_created": "1551276259",
                         "date_modified": "1551276259",
                         "description": "test project #1",
+                        "full_url": "http://localhost.localdomain/test",
                         "fullname": "test",
                         "id": 1,
                         "milestones": {},
@@ -524,6 +530,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "url_path": "test",
                         "user": {
                             "fullname": "PY C",
+                            "full_url": "http://localhost.localdomain/user/pingou",
                             "name": "pingou",
                             "url_path": "user/pingou",
                         },
@@ -533,6 +540,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "fork/pingou/test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -545,6 +553,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "updated_on": "1551276260",
                 "user": {
                     "fullname": "PY C",
+                    "full_url": "http://localhost.localdomain/user/pingou",
                     "name": "pingou",
                     "url_path": "user/pingou",
                 },
@@ -552,8 +561,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         )
 
     def test_api_pull_request_update_edited_linked(self):
-        """ Test api_assign_pull_request method when with valid input
-        """
+        """Test api_assign_pull_request method when with valid input"""
         project = pagure.lib.query.get_authorized_project(self.session, "test")
         self.assertEqual(len(project.requests), 1)
         self.assertEqual(len(project.requests[0].related_issues), 0)
@@ -611,6 +619,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "commit_start": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "commit_stop": "5f5d609db65d447f77ba00e25afd17ba5053344b",
                 "date_created": "1551276260",
+                "full_url": "http://localhost.localdomain/test/pull-request/1",
                 "id": 1,
                 "initial_comment": "Edited initial comment\n\nthis PR "
                 "fixes #2 \n\nThanks",
@@ -639,6 +648,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/test",
                     "fullname": "test",
                     "id": 1,
                     "milestones": {},
@@ -650,6 +660,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -674,6 +685,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "date_created": "1551276259",
                     "date_modified": "1551276259",
                     "description": "test project #1",
+                    "full_url": "http://localhost.localdomain/fork/pingou/test",
                     "fullname": "forks/pingou/test",
                     "id": 4,
                     "milestones": {},
@@ -703,6 +715,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "date_created": "1551276259",
                         "date_modified": "1551276259",
                         "description": "test project #1",
+                        "full_url": "http://localhost.localdomain/test",
                         "fullname": "test",
                         "id": 1,
                         "milestones": {},
@@ -714,6 +727,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                         "url_path": "test",
                         "user": {
                             "fullname": "PY C",
+                            "full_url": "http://localhost.localdomain/user/pingou",
                             "name": "pingou",
                             "url_path": "user/pingou",
                         },
@@ -723,6 +737,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                     "url_path": "fork/pingou/test",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -735,6 +750,7 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
                 "updated_on": "1551276260",
                 "user": {
                     "fullname": "PY C",
+                    "full_url": "http://localhost.localdomain/user/pingou",
                     "name": "pingou",
                     "url_path": "user/pingou",
                 },
@@ -748,5 +764,239 @@ class PagureFlaskApiForkUpdatetests(tests.SimplePagureTest):
         self.assertEqual(len(project.issues[0].related_prs), 1)
 
 
+class PagureFlaskApiForkUpdateNoCommitterTests(tests.SimplePagureTest):
+    """Tests for the flask API of pagure for updating a PR
+    when the PR owner is not a committer in the target project
+    but he is the owner of the PR.
+    """
+
+    maxDiff = None
+
+    @patch("pagure.lib.git.update_git", MagicMock(return_value=True))
+    @patch("pagure.lib.notify.send_email", MagicMock(return_value=True))
+    def setUp(self):
+        """Set up the environnment, ran before every tests.
+
+        Pingou is the owner of the target project (test).
+        Maja has a fork of the test project and creates
+        a PR against Pingou parent project.
+        She should be able to update her own PR.
+        """
+        super(PagureFlaskApiForkUpdateNoCommitterTests, self).setUp()
+
+        tests.create_projects(self.session)
+        tests.add_content_git_repo(
+            os.path.join(self.path, "repos", "test.git")
+        )
+
+        # Fork
+        tests.create_user(self.session, "maja", "Maja M.", ["mm@f.com"])
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        task = pagure.lib.query.fork_project(
+            session=self.session, user="maja", repo=project
+        )
+        self.session.commit()
+        self.assertEqual(
+            task.get(),
+            {
+                "endpoint": "ui_ns.view_repo",
+                "repo": "test",
+                "namespace": None,
+                "username": "maja",
+            },
+        )
+
+        tests.add_readme_git_repo(
+            os.path.join(self.path, "repos", "forks", "maja", "test.git")
+        )
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        fork = pagure.lib.query.get_authorized_project(
+            self.session, "test", user="maja"
+        )
+
+        tests.create_tokens(self.session)
+        tests.create_tokens_acl(self.session)
+
+        req = pagure.lib.query.new_pull_request(
+            session=self.session,
+            repo_from=fork,
+            branch_from="master",
+            repo_to=project,
+            branch_to="master",
+            title="test pull-request",
+            user="maja",
+        )
+        self.session.commit()
+        self.assertEqual(req.id, 1)
+        self.assertEqual(req.title, "test pull-request")
+
+        # Assert the PR is open
+        self.session = pagure.lib.query.create_session(self.dbpath)
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        self.assertEqual(len(project.requests), 1)
+        self.assertEqual(project.requests[0].status, "Open")
+        # Check how the PR renders in the API and the UI
+        output = self.app.get("/api/0/test/pull-request/1")
+        self.assertEqual(output.status_code, 200)
+        output = self.app.get("/test/pull-request/1")
+        self.assertEqual(output.status_code, 200)
+
+    def test_api_pull_request_updated_by_owner(self):
+        """Owners of PRs can update their own PRs."""
+
+        headers = {"Authorization": "token aaabbbcccddd"}
+
+        data = {
+            "title": "edited test PR",
+            "initial_comment": "Edited initial comment",
+        }
+
+        user = tests.FakeUser()
+        user.username = "maja"
+        with tests.user_set(self.app.application, user):
+            output = self.app.post(
+                "/api/0/test/pull-request/1", data=data, headers=headers
+            )
+
+            self.assertEqual(output.status_code, 200)
+
+    def test_api_pull_request_not_updated_by_other_user(self):
+        """No repo committers or PR owners are allowed to update PR."""
+
+        headers = {"Authorization": "token aaabbbcccddd"}
+
+        data = {
+            "title": "edited test PR",
+            "initial_comment": "Edited initial comment",
+        }
+
+        tests.create_user(self.session, "other", "Another User", ["au@rh.com"])
+        user = tests.FakeUser()
+        user.username = "other"
+        with tests.user_set(self.app.application, user):
+            output = self.app.post(
+                "/api/0/test/pull-request/1", data=data, headers=headers
+            )
+
+            self.assertEqual(output.status_code, 403)
+
+
+class PagureFlaskApiForkUpdateNoCommitterTests(tests.SimplePagureTest):
+    """Tests for the flask API of pagure for updating a PR
+    when the PR owner is not a committer in the target project
+    but he is the owner of the PR.
+    """
+
+    maxDiff = None
+
+    @patch("pagure.lib.git.update_git", MagicMock(return_value=True))
+    @patch("pagure.lib.notify.send_email", MagicMock(return_value=True))
+    def setUp(self):
+        """Set up the environnment, ran before every tests.
+
+        Pingou is the owner of the target project (test).
+        Maja has a fork of the test project and creates
+        a PR against Pingou parent project.
+        She should be able to update her own PR.
+        """
+        super(PagureFlaskApiForkUpdateNoCommitterTests, self).setUp()
+
+        tests.create_projects(self.session)
+        tests.add_content_git_repo(
+            os.path.join(self.path, "repos", "test.git")
+        )
+
+        # Fork
+        tests.create_user(self.session, "maja", "Maja M.", ["mm@f.com"])
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        task = pagure.lib.query.fork_project(
+            session=self.session, user="maja", repo=project
+        )
+        self.session.commit()
+        self.assertEqual(
+            task.get(),
+            {
+                "endpoint": "ui_ns.view_repo",
+                "repo": "test",
+                "namespace": None,
+                "username": "maja",
+            },
+        )
+
+        tests.add_readme_git_repo(
+            os.path.join(self.path, "repos", "forks", "maja", "test.git")
+        )
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        fork = pagure.lib.query.get_authorized_project(
+            self.session, "test", user="maja"
+        )
+
+        tests.create_tokens(self.session)
+        tests.create_tokens_acl(self.session)
+
+        req = pagure.lib.query.new_pull_request(
+            session=self.session,
+            repo_from=fork,
+            branch_from="master",
+            repo_to=project,
+            branch_to="master",
+            title="test pull-request",
+            user="maja",
+        )
+        self.session.commit()
+        self.assertEqual(req.id, 1)
+        self.assertEqual(req.title, "test pull-request")
+
+        # Assert the PR is open
+        self.session = pagure.lib.query.create_session(self.dbpath)
+        project = pagure.lib.query.get_authorized_project(self.session, "test")
+        self.assertEqual(len(project.requests), 1)
+        self.assertEqual(project.requests[0].status, "Open")
+        # Check how the PR renders in the API and the UI
+        output = self.app.get("/api/0/test/pull-request/1")
+        self.assertEqual(output.status_code, 200)
+        output = self.app.get("/test/pull-request/1")
+        self.assertEqual(output.status_code, 200)
+
+    def test_api_pull_request_updated_by_owner(self):
+        """Owners of PRs can update their own PRs."""
+
+        headers = {"Authorization": "token aaabbbcccddd"}
+
+        data = {
+            "title": "edited test PR",
+            "initial_comment": "Edited initial comment",
+        }
+
+        user = tests.FakeUser()
+        user.username = "maja"
+        with tests.user_set(self.app.application, user):
+            output = self.app.post(
+                "/api/0/test/pull-request/1", data=data, headers=headers
+            )
+
+            self.assertEqual(output.status_code, 200)
+
+    def test_api_pull_request_not_updated_by_other_user(self):
+        """No repo committers or PR owners are allowed to update PR."""
+
+        headers = {"Authorization": "token aaabbbcccddd"}
+
+        data = {
+            "title": "edited test PR",
+            "initial_comment": "Edited initial comment",
+        }
+
+        tests.create_user(self.session, "other", "Another User", ["au@rh.com"])
+        user = tests.FakeUser()
+        user.username = "other"
+        with tests.user_set(self.app.application, user):
+            output = self.app.post(
+                "/api/0/test/pull-request/1", data=data, headers=headers
+            )
+
+            self.assertEqual(output.status_code, 403)
+
+
 if __name__ == "__main__":
     unittest.main(verbosity=2)
