@@ -65,8 +65,8 @@ class PagureFlaskApiUSertests(tests.Modeltests):
 
     def test_api_view_user(self):
         """
-            Test the api_view_user method of the flask api
-            The tested user has no project or forks.
+        Test the api_view_user method of the flask api
+        The tested user has no project or forks.
         """
         output = self.app.get("/api/0/user/pingou")
         self.assertEqual(output.status_code, 200)
@@ -95,6 +95,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                 "fullname": "PY C",
                 "name": "pingou",
                 "url_path": "user/pingou",
+                "full_url": "http://localhost.localdomain/user/pingou",
                 "avatar_url": "https://seccdn.libravatar.org/avatar/...",
             },
         }
@@ -108,8 +109,8 @@ class PagureFlaskApiUSertests(tests.Modeltests):
 
     def test_api_view_user_with_project(self):
         """
-            Test the api_view_user method of the flask api,
-            this time the user has some project defined.
+        Test the api_view_user method of the flask api,
+        this time the user has some project defined.
         """
         tests.create_projects(self.session)
 
@@ -164,6 +165,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "description": "test project #1",
                     "fullname": "test",
                     "url_path": "test",
+                    "full_url": "http://localhost.localdomain/test",
                     "id": 1,
                     "milestones": {},
                     "name": "test",
@@ -175,6 +177,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                         "fullname": "PY C",
                         "name": "pingou",
                         "url_path": "user/pingou",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                     },
                 },
                 {
@@ -201,6 +204,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "date_created": "1490272832",
                     "date_modified": "1490272832",
                     "description": "test project #2",
+                    "full_url": "http://localhost.localdomain/test2",
                     "fullname": "test2",
                     "url_path": "test2",
                     "id": 2,
@@ -214,6 +218,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                         "fullname": "PY C",
                         "name": "pingou",
                         "url_path": "user/pingou",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                     },
                 },
                 {
@@ -242,6 +247,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "description": "namespaced test project",
                     "fullname": "somenamespace/test3",
                     "url_path": "somenamespace/test3",
+                    "full_url": "http://localhost.localdomain/somenamespace/test3",
                     "id": 3,
                     "milestones": {},
                     "name": "test3",
@@ -251,6 +257,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "tags": [],
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -269,6 +276,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                 "fullname": "PY C",
                 "name": "pingou",
                 "url_path": "user/pingou",
+                "full_url": "http://localhost.localdomain/user/pingou",
                 "avatar_url": "https://seccdn.libravatar.org/avatar/...",
             },
         }
@@ -277,8 +285,8 @@ class PagureFlaskApiUSertests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_activity_stats(self, mockemail):
-        """ Test the api_view_user_activity_stats method of the flask user
-        api. """
+        """Test the api_view_user_activity_stats method of the flask user
+        api."""
         mockemail.return_value = True
 
         tests.create_projects(self.session)
@@ -351,8 +359,8 @@ class PagureFlaskApiUSertests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_activity_date(self, mockemail):
-        """ Test the api_view_user_activity_date method of the flask user
-        api. """
+        """Test the api_view_user_activity_date method of the flask user
+        api."""
 
         self.test_api_view_user_activity_stats()
 
@@ -421,6 +429,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "type": "created",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -435,6 +444,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "type": "commented",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -449,6 +459,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "type": "closed",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -463,6 +474,7 @@ class PagureFlaskApiUSertests(tests.Modeltests):
                     "type": "commented",
                     "user": {
                         "fullname": "PY C",
+                        "full_url": "http://localhost.localdomain/user/pingou",
                         "name": "pingou",
                         "url_path": "user/pingou",
                     },
@@ -478,8 +490,8 @@ class PagureFlaskApiUSertests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_activity_date_1_activity(self, mockemail):
-        """ Test the api_view_user_activity_date method of the flask user
-        api when the user only did one action. """
+        """Test the api_view_user_activity_date method of the flask user
+        api when the user only did one action."""
 
         tests.create_projects(self.session)
         repo = pagure.lib.query._get_project(self.session, "test")
@@ -947,8 +959,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_filed(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api """
+        """Test the api_view_user_requests_filed method of the flask user
+        api"""
 
         # First we test without the status parameter. It should default to `open`
         output = self.app.get("/api/0/user/pingou/requests/filed")
@@ -1119,8 +1131,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_filed_created(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1192,8 +1204,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_filed_updated(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1202,7 +1214,7 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 0)
+        self.assertEqual(len(data["requests"]), 6)
 
         yesterday = today - datetime.timedelta(days=1)
         output = self.app.get(
@@ -1211,7 +1223,7 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 0)
+        self.assertEqual(len(data["requests"]), 6)
 
         tomorrow = today + datetime.timedelta(days=1)
         output = self.app.get(
@@ -1220,12 +1232,12 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 6)
+        self.assertEqual(len(data["requests"]), 0)
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_filed_closed(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1256,8 +1268,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_filed_foo(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api """
+        """Test the api_view_user_requests_filed method of the flask user
+        api"""
 
         # Default data returned
         output = self.app.get(
@@ -1327,8 +1339,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_actionable(self, mockemail):
-        """ Test the api_view_user_requests_actionable method of the flask user
-        api """
+        """Test the api_view_user_requests_actionable method of the flask user
+        api"""
 
         # First we test without the status parameter. It should default to `open`
         output = self.app.get("/api/0/user/pingou/requests/actionable")
@@ -1503,8 +1515,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_actionable_created(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1576,8 +1588,8 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_actionable_updated(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1586,7 +1598,7 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 0)
+        self.assertEqual(len(data["requests"]), 6)
 
         yesterday = today - datetime.timedelta(days=1)
         output = self.app.get(
@@ -1595,7 +1607,7 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 0)
+        self.assertEqual(len(data["requests"]), 6)
 
         tomorrow = today + datetime.timedelta(days=1)
         output = self.app.get(
@@ -1604,12 +1616,12 @@ class PagureFlaskApiUsertestrequests(tests.Modeltests):
         )
         self.assertEqual(output.status_code, 200)
         data = json.loads(output.get_data(as_text=True))
-        self.assertEqual(len(data["requests"]), 6)
+        self.assertEqual(len(data["requests"]), 0)
 
     @patch("pagure.lib.notify.send_email")
     def test_api_view_user_requests_actionable_closed(self, mockemail):
-        """ Test the api_view_user_requests_filed method of the flask user
-        api with the created parameter """
+        """Test the api_view_user_requests_filed method of the flask user
+        api with the created parameter"""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
@@ -1768,6 +1780,7 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                         "content": "We should work on this",
                         "custom_fields": [],
                         "date_created": "1513111778",
+                        "full_url": "http://localhost.localdomain/test/issue/1",
                         "depends": [],
                         "id": 1,
                         "last_updated": "1513111778",
@@ -1798,6 +1811,7 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                             "date_created": "1513111778",
                             "date_modified": "1513111778",
                             "description": "test project #1",
+                            "full_url": "http://localhost.localdomain/test",
                             "fullname": "test",
                             "id": 1,
                             "milestones": {},
@@ -1809,6 +1823,7 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                             "url_path": "test",
                             "user": {
                                 "fullname": "PY C",
+                                "full_url": "http://localhost.localdomain/user/pingou",
                                 "name": "pingou",
                                 "url_path": "user/pingou",
                             },
@@ -1819,6 +1834,7 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
                         "title": "Test issue",
                         "user": {
                             "fullname": "PY C",
+                            "full_url": "http://localhost.localdomain/user/pingou",
                             "name": "pingou",
                             "url_path": "user/pingou",
                         },
@@ -1850,8 +1866,8 @@ class PagureFlaskApiUsertestissues(tests.Modeltests):
         )
 
     def test_user_issues_created(self):
-        """ Return the list of issues associated with the specified user
-        and play with the created filter. """
+        """Return the list of issues associated with the specified user
+        and play with the created filter."""
 
         today = datetime.datetime.utcnow().date()
         output = self.app.get(
