@@ -149,6 +149,30 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
         items = pagure.lib.query.search_user(self.session)
         self.assertEqual(3, len(items))
 
+    @patch.dict("pagure.config.config", {"PAGURE_AUTH": "local"})
+    @patch.dict("pagure.config.config", {"ALLOW_USER_REGISTRATION": False})
+    @patch("pagure.lib.notify.send_email", MagicMock(return_value=True))
+    def test_new_user_disabled(self):
+        """ Test the disabling of the new_user endpoint. """
+
+        # Check before:
+        items = pagure.lib.query.search_user(self.session)
+        self.assertEqual(2, len(items))
+
+        # Attempt to access the new user page
+        output = self.app.get("/user/new", follow_redirects=True)
+        self.assertEqual(output.status_code, 200)
+        self.assertIn(
+            "<title>Login - Pagure</title>", output.get_data(as_text=True)
+        )
+        self.assertIn(
+            "User registration is disabled.", output.get_data(as_text=True)
+        )
+
+        # Check after:
+        items = pagure.lib.query.search_user(self.session)
+        self.assertEqual(2, len(items))
+
     @patch.dict("pagure.config.config", {"PAGURE_AUTH": "local"})
     @patch.dict("pagure.config.config", {"CHECK_SESSION_IP": False})
     def test_do_login(self):
@@ -273,8 +297,8 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
         self.assertEqual(item.user, "foouser")
         self.assertEqual(item.token, None)
 
-        # Login but cannot save the session to the DB due to the missing IP
-        # address in the flask request
+        # Login works but cannot save the session to the DB due to the missing
+        # IP address in the flask request
         data["password"] = "barpass"
         output = self.app.post("/dologin", data=data, follow_redirects=True)
         self.assertEqual(output.status_code, 200)
@@ -338,7 +362,8 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
             output.get_data(as_text=True),
         )
         self.assertIn(
-            "Username or password invalid.", output.get_data(as_text=True),
+            "Username or password invalid.",
+            output.get_data(as_text=True),
         )
 
         # Check the password is still not of a known version
@@ -449,11 +474,15 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
             '<span class="d-none d-md-inline">Settings</span>', output_text
         )
 
+        output = self.app.get("/login/?next=%2f%2f%09%2fgoogle.fr")
+        self.assertEqual(output.status_code, 302)
+        self.assertEqual(output.location, "http://localhost/google.fr")
+
     @patch.dict("pagure.config.config", {"PAGURE_AUTH": "local"})
     @patch.dict("pagure.config.config", {"CHECK_SESSION_IP": False})
     def test_has_settings(self):
-        """ Test that user can see the Settings button when they are logged
-        in. """
+        """Test that user can see the Settings button when they are logged
+        in."""
         # Create a local user
         self.test_new_user()
         self.session.commit()
@@ -493,8 +522,8 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
     @patch.dict("pagure.config.config", {"PAGURE_AUTH": "local"})
     @patch("pagure.lib.notify.send_email", MagicMock(return_value=True))
     def test_non_ascii_password(self):
-        """ Test login and create user functionality when the password is
-            non-ascii.
+        """Test login and user creation functionality when the password is
+        non-ascii.
         """
 
         # Check before:
@@ -1043,6 +1072,14 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
                 output.get_data(as_text=True),
             )
 
+        user = tests.FakeUser(username="foo")
+        with tests.user_set(self.app.application, user):
+            output = self.app.get("/logout/?next=%2f%2f%09%2fgoogle.fr")
+            self.assertEqual(output.status_code, 302)
+            self.assertTrue(
+                output.headers["location"] in ("http://localhost/google.fr",)
+            )
+
     @patch.dict("pagure.config.config", {"PAGURE_AUTH": "local"})
     def test_settings_admin_session_timedout(self):
         """ Test the admin_session_timedout with settings endpoint. """
@@ -1060,7 +1097,14 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
             # redirect again for the login page
             output = self.app.get("/settings/")
             self.assertEqual(output.status_code, 302)
-            self.assertIn("http://localhost/login/", output.location)
+            self.assertTrue(
+                output.location
+                in (
+                    "http://localhost/login/",
+                    "/login/?next=http%3A%2F%2Flocalhost%2Fsettings%2F",
+                    "http://localhost/login/?next=http%3A%2F%2Flocalhost%2Fsettings%2F",
+                )
+            )
         # session did not expire
         user.login_time = datetime.datetime.utcnow() - lifetime + td1
         with tests.user_set(self.app.application, user):
@@ -1102,14 +1146,17 @@ class PagureFlaskLogintests(tests.SimplePagureTest):
             data = {"csrf_token": self.get_csrf()}
             output = self.app.post("/settings/forcelogout/", data=data)
             self.assertEqual(output.status_code, 302)
-            self.assertEqual(
-                output.headers["Location"], "http://localhost/settings"
+            self.assertTrue(
+                output.headers["Location"]
+                in ("http://localhost/settings", "/settings")
             )
 
             # We should now get redirected to index, because our session became
             # invalid
             output = self.app.get("/settings")
-            self.assertEqual(output.headers["Location"], "http://localhost/")
+            self.assertTrue(
+                output.headers["Location"] in ("http://localhost/", "/")
+            )
 
             # After changing the login_time to now, the session should again be
             # valid
