@@ -25,6 +25,7 @@ import pagure.lib.model
 import pagure.lib.notify
 import pagure.lib.query
 import tests
+import munch
 
 
 class PagureLibNotifytests(tests.Modeltests):
@@ -499,8 +500,8 @@ RW1haWwgY29udGVudA==
     @patch.dict("pagure.config.config", {"EVENTSOURCE_SOURCE": None})
     @patch("pagure.lib.notify.smtplib.SMTP")
     def test_send_email_no_reply_to(self, mock_smtp):
-        """ Test the send_email method from pagure.lib.notify when there
-        should not be a Reply-To header even if mail_id is defined. """
+        """Test the send_email method from pagure.lib.notify when there
+        should not be a Reply-To header even if mail_id is defined."""
         mock_smtp.return_value = MagicMock()
 
         email = pagure.lib.notify.send_email(
@@ -543,6 +544,31 @@ RW1haWwgY29udGVudA==
 """
         self.assertEqual(email.as_string(), exp)
 
+    def test_notification_mention(self):
+        g = munch.Munch()
+        g.session = self.session
+        with patch("flask.g", g):
+
+            def _check_mention(comment, exp):
+                emails = set([])
+                emails = pagure.lib.notify._add_mentioned_users(
+                    emails, comment
+                )
+
+                self.assertEqual(emails, exp)
+
+            exp = set(["bar@pingou.com"])
+            comment = "I think we should ask @pingou how to pronounce pagure"
+            _check_mention(comment, exp)
+
+            exp = set([])
+            comment = """Let me quote him:
+~~~~
+ @pingou> Pagure is pronounced 'pa-gure', not 'pagu-re'
+~~~~
+"""
+            _check_mention(comment, exp)
+
 
 if __name__ == "__main__":
     unittest.main(verbosity=2)
